package Bio::Emboss::Methods;

# automatically generated by scripts/get_methods.pl on Wed Feb  8 14:30:11 2006

# This file defines the methods that are available for certain classes
# (i.e. certain EMBOSS types "AjP...")
#
# If an EMBOSS library function has an AjP... type as a first parameter,
# this function can be used as a method on that data type.
#
# This information is extracted from .xs files by "scripts/get_methods.pl"
#
# Bio::Emboss.pm can EXPORT several functions on request into the callers
# namespace. Lists of functions are created for some EXPORT tags.


*Bio::Emboss::3dVector::aj3dVectorAngle = *Bio::Emboss::aj3dVectorAngle;
*Bio::Emboss::3dVector::aj3dVectorBetweenPoints = *Bio::Emboss::aj3dVectorBetweenPoints;
*Bio::Emboss::3dVector::aj3dVectorCrossProduct = *Bio::Emboss::aj3dVectorCrossProduct;
*Bio::Emboss::3dVector::aj3dVectorDihedralAngle = *Bio::Emboss::aj3dVectorDihedralAngle;
*Bio::Emboss::3dVector::aj3dVectorDel = *Bio::Emboss::aj3dVectorDel;
*Bio::Emboss::3dVector::aj3dVectorDotProduct = *Bio::Emboss::aj3dVectorDotProduct;
*Bio::Emboss::3dVector::aj3dVectorLength = *Bio::Emboss::aj3dVectorLength;
*Bio::Emboss::3dVector::aj3dVectorSum = *Bio::Emboss::aj3dVectorSum;

*Bio::Emboss::Align::ajAlignClose = *Bio::Emboss::ajAlignClose;
*Bio::Emboss::Align::ajAlignDefine = *Bio::Emboss::ajAlignDefine;
*Bio::Emboss::Align::ajAlignDefineSS = *Bio::Emboss::ajAlignDefineSS;
*Bio::Emboss::Align::ajAlignDefineCC = *Bio::Emboss::ajAlignDefineCC;
*Bio::Emboss::Align::ajAlignDel = *Bio::Emboss::ajAlignDel;
*Bio::Emboss::Align::ajAlignOpen = *Bio::Emboss::ajAlignOpen;
*Bio::Emboss::Align::ajAlignReset = *Bio::Emboss::ajAlignReset;
*Bio::Emboss::Align::ajAlignSetHeader = *Bio::Emboss::ajAlignSetHeader;
*Bio::Emboss::Align::ajAlignSetHeaderApp = *Bio::Emboss::ajAlignSetHeaderApp;
*Bio::Emboss::Align::ajAlignSetHeaderC = *Bio::Emboss::ajAlignSetHeaderC;
*Bio::Emboss::Align::ajAlignSetGapI = *Bio::Emboss::ajAlignSetGapI;
*Bio::Emboss::Align::ajAlignSetGapR = *Bio::Emboss::ajAlignSetGapR;
*Bio::Emboss::Align::ajAlignSetMatrixName = *Bio::Emboss::ajAlignSetMatrixName;
*Bio::Emboss::Align::ajAlignSetMatrixNameC = *Bio::Emboss::ajAlignSetMatrixNameC;
*Bio::Emboss::Align::ajAlignSetMatrixInt = *Bio::Emboss::ajAlignSetMatrixInt;
*Bio::Emboss::Align::ajAlignSetMatrixFloat = *Bio::Emboss::ajAlignSetMatrixFloat;
*Bio::Emboss::Align::ajAlignSetRange = *Bio::Emboss::ajAlignSetRange;
*Bio::Emboss::Align::ajAlignSetScoreI = *Bio::Emboss::ajAlignSetScoreI;
*Bio::Emboss::Align::ajAlignSetScoreR = *Bio::Emboss::ajAlignSetScoreR;
*Bio::Emboss::Align::ajAlignSetSubHeader = *Bio::Emboss::ajAlignSetSubHeader;
*Bio::Emboss::Align::ajAlignSetSubHeaderApp = *Bio::Emboss::ajAlignSetSubHeaderApp;
*Bio::Emboss::Align::ajAlignSetSubHeaderC = *Bio::Emboss::ajAlignSetSubHeaderC;
*Bio::Emboss::Align::ajAlignSetSubHeaderPre = *Bio::Emboss::ajAlignSetSubHeaderPre;
*Bio::Emboss::Align::ajAlignSetStats = *Bio::Emboss::ajAlignSetStats;
*Bio::Emboss::Align::ajAlignSetSubRange = *Bio::Emboss::ajAlignSetSubRange;
*Bio::Emboss::Align::ajAlignSetSubStandard = *Bio::Emboss::ajAlignSetSubStandard;
*Bio::Emboss::Align::ajAlignSetTail = *Bio::Emboss::ajAlignSetTail;
*Bio::Emboss::Align::ajAlignSetTailApp = *Bio::Emboss::ajAlignSetTailApp;
*Bio::Emboss::Align::ajAlignSetTailC = *Bio::Emboss::ajAlignSetTailC;
*Bio::Emboss::Align::ajAlignSetType = *Bio::Emboss::ajAlignSetType;
*Bio::Emboss::Align::ajAlignTrace = *Bio::Emboss::ajAlignTrace;
*Bio::Emboss::Align::ajAlignTraceT = *Bio::Emboss::ajAlignTraceT;
*Bio::Emboss::Align::ajAlignValid = *Bio::Emboss::ajAlignValid;
*Bio::Emboss::Align::ajAlignWrite = *Bio::Emboss::ajAlignWrite;
*Bio::Emboss::Align::ajAlignWriteHeader = *Bio::Emboss::ajAlignWriteHeader;
*Bio::Emboss::Align::ajAlignWriteTail = *Bio::Emboss::ajAlignWriteTail;

*Bio::Emboss::Atom::ajAtomDel = *Bio::Emboss::ajAtomDel;
*Bio::Emboss::Atom::ajAtomCopy = *Bio::Emboss::ajAtomCopy;
*Bio::Emboss::Atom::ajAtomEnv13 = *Bio::Emboss::ajAtomEnv13;
*Bio::Emboss::Atom::ajXyzAtomDel = *Bio::Emboss::ajXyzAtomDel;
*Bio::Emboss::Atom::ajXyzInContact = *Bio::Emboss::ajXyzInContact;
*Bio::Emboss::Atom::ajXyzAtomDistance = *Bio::Emboss::ajXyzAtomDistance;
*Bio::Emboss::Atom::ajXyzVdwRad = *Bio::Emboss::ajXyzVdwRad;
*Bio::Emboss::Atom::embAtomInContact = *Bio::Emboss::embAtomInContact;
*Bio::Emboss::Atom::embAtomDistance = *Bio::Emboss::embAtomDistance;
*Bio::Emboss::Atom::embVdwRad = *Bio::Emboss::embVdwRad;

*Bio::Emboss::BtId::ajBtreeIdDel = *Bio::Emboss::ajBtreeIdDel;

*Bio::Emboss::BtKeyWild::ajBtreeKeyWildDel = *Bio::Emboss::ajBtreeKeyWildDel;

*Bio::Emboss::BtPri::ajBtreePriDel = *Bio::Emboss::ajBtreePriDel;

*Bio::Emboss::BtWild::ajBtreeWildDel = *Bio::Emboss::ajBtreeWildDel;

*Bio::Emboss::Btcache::ajBtreeCacheRead = *Bio::Emboss::ajBtreeCacheRead;
*Bio::Emboss::Btcache::ajBtreeCacheWrite = *Bio::Emboss::ajBtreeCacheWrite;
*Bio::Emboss::Btcache::ajBtreeCreateRootNode = *Bio::Emboss::ajBtreeCreateRootNode;
*Bio::Emboss::Btcache::ajBtreeFindInsert = *Bio::Emboss::ajBtreeFindInsert;
*Bio::Emboss::Btcache::ajBtreeCacheDel = *Bio::Emboss::ajBtreeCacheDel;
*Bio::Emboss::Btcache::ajBtreeInsertId = *Bio::Emboss::ajBtreeInsertId;
*Bio::Emboss::Btcache::ajBtreeIdFromKey = *Bio::Emboss::ajBtreeIdFromKey;
*Bio::Emboss::Btcache::ajBtreeWriteParams = *Bio::Emboss::ajBtreeWriteParams;
*Bio::Emboss::Btcache::ajBtreeCacheSync = *Bio::Emboss::ajBtreeCacheSync;
*Bio::Emboss::Btcache::ajBtreeDeleteId = *Bio::Emboss::ajBtreeDeleteId;
*Bio::Emboss::Btcache::ajBtreeWildNew = *Bio::Emboss::ajBtreeWildNew;
*Bio::Emboss::Btcache::ajBtreeKeyWildNew = *Bio::Emboss::ajBtreeKeyWildNew;
*Bio::Emboss::Btcache::ajBtreeFindInsertW = *Bio::Emboss::ajBtreeFindInsertW;
*Bio::Emboss::Btcache::ajBtreeIdFromKeyW = *Bio::Emboss::ajBtreeIdFromKeyW;
*Bio::Emboss::Btcache::ajBtreeListFromKeyW = *Bio::Emboss::ajBtreeListFromKeyW;
*Bio::Emboss::Btcache::ajBtreeIdFromKeywordW = *Bio::Emboss::ajBtreeIdFromKeywordW;
*Bio::Emboss::Btcache::ajBtreeListFromKeywordW = *Bio::Emboss::ajBtreeListFromKeywordW;
*Bio::Emboss::Btcache::ajBtreeReplaceId = *Bio::Emboss::ajBtreeReplaceId;
*Bio::Emboss::Btcache::ajBtreeInsertDupId = *Bio::Emboss::ajBtreeInsertDupId;
*Bio::Emboss::Btcache::ajBtreeDupFromKey = *Bio::Emboss::ajBtreeDupFromKey;
*Bio::Emboss::Btcache::ajBtreePriFromKeyword = *Bio::Emboss::ajBtreePriFromKeyword;
*Bio::Emboss::Btcache::ajBtreeSecFindInsert = *Bio::Emboss::ajBtreeSecFindInsert;
*Bio::Emboss::Btcache::ajBtreeInsertSecId = *Bio::Emboss::ajBtreeInsertSecId;
*Bio::Emboss::Btcache::ajBtreeSecFromId = *Bio::Emboss::ajBtreeSecFromId;
*Bio::Emboss::Btcache::ajBtreeSecLeafList = *Bio::Emboss::ajBtreeSecLeafList;
*Bio::Emboss::Btcache::ajBtreeVerifyId = *Bio::Emboss::ajBtreeVerifyId;
*Bio::Emboss::Btcache::ajBtreeInsertKeyword = *Bio::Emboss::ajBtreeInsertKeyword;
*Bio::Emboss::Btcache::ajBtreeLockTest = *Bio::Emboss::ajBtreeLockTest;

*Bio::Emboss::Cath::ajCathDel = *Bio::Emboss::ajCathDel;
*Bio::Emboss::Cath::ajCathCopy = *Bio::Emboss::ajCathCopy;
*Bio::Emboss::Cath::ajCathArrFindPdbid = *Bio::Emboss::ajCathArrFindPdbid;

*Bio::Emboss::Chain::ajChainDel = *Bio::Emboss::ajChainDel;
*Bio::Emboss::Chain::ajXyzChainDel = *Bio::Emboss::ajXyzChainDel;

*Bio::Emboss::Cmap::ajCmapDel = *Bio::Emboss::ajCmapDel;
*Bio::Emboss::Cmap::ajXyzCmapDel = *Bio::Emboss::ajXyzCmapDel;

*Bio::Emboss::Cod::ajCodAssCode = *Bio::Emboss::ajCodAssCode;
*Bio::Emboss::Cod::ajCodAssDesc = *Bio::Emboss::ajCodAssDesc;
*Bio::Emboss::Cod::ajCodAssDescC = *Bio::Emboss::ajCodAssDescC;
*Bio::Emboss::Cod::ajCodAssDivision = *Bio::Emboss::ajCodAssDivision;
*Bio::Emboss::Cod::ajCodAssDivisionC = *Bio::Emboss::ajCodAssDivisionC;
*Bio::Emboss::Cod::ajCodAssNumcds = *Bio::Emboss::ajCodAssNumcds;
*Bio::Emboss::Cod::ajCodAssNumcodon = *Bio::Emboss::ajCodAssNumcodon;
*Bio::Emboss::Cod::ajCodAssRelease = *Bio::Emboss::ajCodAssRelease;
*Bio::Emboss::Cod::ajCodAssReleaseC = *Bio::Emboss::ajCodAssReleaseC;
*Bio::Emboss::Cod::ajCodAssSpecies = *Bio::Emboss::ajCodAssSpecies;
*Bio::Emboss::Cod::ajCodAssSpeciesC = *Bio::Emboss::ajCodAssSpeciesC;
*Bio::Emboss::Cod::ajCodAssName = *Bio::Emboss::ajCodAssName;
*Bio::Emboss::Cod::ajCodAssNameC = *Bio::Emboss::ajCodAssNameC;
*Bio::Emboss::Cod::ajCodCai = *Bio::Emboss::ajCodCai;
*Bio::Emboss::Cod::ajCodCalcGribskov = *Bio::Emboss::ajCodCalcGribskov;
*Bio::Emboss::Cod::ajCodCalcCai = *Bio::Emboss::ajCodCalcCai;
*Bio::Emboss::Cod::ajCodCalcNc = *Bio::Emboss::ajCodCalcNc;
*Bio::Emboss::Cod::ajCodCalculateUsage = *Bio::Emboss::ajCodCalculateUsage;
*Bio::Emboss::Cod::ajCodClear = *Bio::Emboss::ajCodClear;
*Bio::Emboss::Cod::ajCodClearData = *Bio::Emboss::ajCodClearData;
*Bio::Emboss::Cod::ajCodCountTriplets = *Bio::Emboss::ajCodCountTriplets;
*Bio::Emboss::Cod::ajCodDel = *Bio::Emboss::ajCodDel;
*Bio::Emboss::Cod::ajCodDup = *Bio::Emboss::ajCodDup;
*Bio::Emboss::Cod::ajCodGetCode = *Bio::Emboss::ajCodGetCode;
*Bio::Emboss::Cod::ajCodGetDesc = *Bio::Emboss::ajCodGetDesc;
*Bio::Emboss::Cod::ajCodGetDescC = *Bio::Emboss::ajCodGetDescC;
*Bio::Emboss::Cod::ajCodGetDivision = *Bio::Emboss::ajCodGetDivision;
*Bio::Emboss::Cod::ajCodGetDivisionC = *Bio::Emboss::ajCodGetDivisionC;
*Bio::Emboss::Cod::ajCodGetName = *Bio::Emboss::ajCodGetName;
*Bio::Emboss::Cod::ajCodGetNameC = *Bio::Emboss::ajCodGetNameC;
*Bio::Emboss::Cod::ajCodGetNumcds = *Bio::Emboss::ajCodGetNumcds;
*Bio::Emboss::Cod::ajCodGetNumcodon = *Bio::Emboss::ajCodGetNumcodon;
*Bio::Emboss::Cod::ajCodGetRelease = *Bio::Emboss::ajCodGetRelease;
*Bio::Emboss::Cod::ajCodGetReleaseC = *Bio::Emboss::ajCodGetReleaseC;
*Bio::Emboss::Cod::ajCodGetSpecies = *Bio::Emboss::ajCodGetSpecies;
*Bio::Emboss::Cod::ajCodGetSpeciesC = *Bio::Emboss::ajCodGetSpeciesC;
*Bio::Emboss::Cod::ajCodRead = *Bio::Emboss::ajCodRead;
*Bio::Emboss::Cod::ajCodSetBacktranslate = *Bio::Emboss::ajCodSetBacktranslate;
*Bio::Emboss::Cod::ajCodWrite = *Bio::Emboss::ajCodWrite;
*Bio::Emboss::Cod::ajCodWriteOut = *Bio::Emboss::ajCodWriteOut;

*Bio::Emboss::Dir::ajDirDel = *Bio::Emboss::ajDirDel;
*Bio::Emboss::Dir::ajDiroutDel = *Bio::Emboss::ajDiroutDel;
*Bio::Emboss::Dir::ajDirExt = *Bio::Emboss::ajDirExt;
*Bio::Emboss::Dir::ajDirName = *Bio::Emboss::ajDirName;
*Bio::Emboss::Dir::ajFileNewDirF = *Bio::Emboss::ajFileNewDirF;
*Bio::Emboss::Dir::ajFileNewOutDir = *Bio::Emboss::ajFileNewOutDir;

*Bio::Emboss::Domain::ajDomainDel = *Bio::Emboss::ajDomainDel;
*Bio::Emboss::Domain::ajDomainCopy = *Bio::Emboss::ajDomainCopy;
*Bio::Emboss::Domain::ajDomainGetId = *Bio::Emboss::ajDomainGetId;
*Bio::Emboss::Domain::ajDomainGetSeqPdb = *Bio::Emboss::ajDomainGetSeqPdb;
*Bio::Emboss::Domain::ajDomainGetSeqSpr = *Bio::Emboss::ajDomainGetSeqSpr;
*Bio::Emboss::Domain::ajDomainGetPdb = *Bio::Emboss::ajDomainGetPdb;
*Bio::Emboss::Domain::ajDomainGetAcc = *Bio::Emboss::ajDomainGetAcc;
*Bio::Emboss::Domain::ajDomainGetSpr = *Bio::Emboss::ajDomainGetSpr;
*Bio::Emboss::Domain::ajDomainGetN = *Bio::Emboss::ajDomainGetN;

*Bio::Emboss::FeattabIn::ajFeatRead = *Bio::Emboss::ajFeatRead;
*Bio::Emboss::FeattabIn::ajFeattabInClear = *Bio::Emboss::ajFeattabInClear;
*Bio::Emboss::FeattabIn::ajFeattabInDel = *Bio::Emboss::ajFeattabInDel;
*Bio::Emboss::FeattabIn::ajFeattabInSetType = *Bio::Emboss::ajFeattabInSetType;
*Bio::Emboss::FeattabIn::ajFeattabInSetTypeC = *Bio::Emboss::ajFeattabInSetTypeC;
*Bio::Emboss::FeattabIn::ajFeatUfoRead = *Bio::Emboss::ajFeatUfoRead;

*Bio::Emboss::FeattabOut::ajFeattabOutDel = *Bio::Emboss::ajFeattabOutDel;
*Bio::Emboss::FeattabOut::ajFeattabOutFile = *Bio::Emboss::ajFeattabOutFile;
*Bio::Emboss::FeattabOut::ajFeattabOutFilename = *Bio::Emboss::ajFeattabOutFilename;
*Bio::Emboss::FeattabOut::ajFeattabOutIsLocal = *Bio::Emboss::ajFeattabOutIsLocal;
*Bio::Emboss::FeattabOut::ajFeattabOutIsOpen = *Bio::Emboss::ajFeattabOutIsOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutOpen = *Bio::Emboss::ajFeattabOutOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutSet = *Bio::Emboss::ajFeattabOutSet;
*Bio::Emboss::FeattabOut::ajFeattabOutSetBasename = *Bio::Emboss::ajFeattabOutSetBasename;
*Bio::Emboss::FeattabOut::ajFeattabOutSetType = *Bio::Emboss::ajFeattabOutSetType;
*Bio::Emboss::FeattabOut::ajFeattabOutSetTypeC = *Bio::Emboss::ajFeattabOutSetTypeC;
*Bio::Emboss::FeattabOut::ajFeatWrite = *Bio::Emboss::ajFeatWrite;

*Bio::Emboss::Feattable::ajFeatNew = *Bio::Emboss::ajFeatNew;
*Bio::Emboss::Feattable::ajFeatNewII = *Bio::Emboss::ajFeatNewII;
*Bio::Emboss::Feattable::ajFeatNewIIRev = *Bio::Emboss::ajFeatNewIIRev;
*Bio::Emboss::Feattable::ajFeatNewProt = *Bio::Emboss::ajFeatNewProt;
*Bio::Emboss::Feattable::ajFeatSortByEnd = *Bio::Emboss::ajFeatSortByEnd;
*Bio::Emboss::Feattable::ajFeatSortByStart = *Bio::Emboss::ajFeatSortByStart;
*Bio::Emboss::Feattable::ajFeatSortByType = *Bio::Emboss::ajFeatSortByType;
*Bio::Emboss::Feattable::ajFeattableAdd = *Bio::Emboss::ajFeattableAdd;
*Bio::Emboss::Feattable::ajFeattableBegin = *Bio::Emboss::ajFeattableBegin;
*Bio::Emboss::Feattable::ajFeattableClear = *Bio::Emboss::ajFeattableClear;
*Bio::Emboss::Feattable::ajFeattableCopy = *Bio::Emboss::ajFeattableCopy;
*Bio::Emboss::Feattable::ajFeattableDel = *Bio::Emboss::ajFeattableDel;
*Bio::Emboss::Feattable::ajFeattableEnd = *Bio::Emboss::ajFeattableEnd;
*Bio::Emboss::Feattable::ajFeattableGetName = *Bio::Emboss::ajFeattableGetName;
*Bio::Emboss::Feattable::ajFeattableIsNuc = *Bio::Emboss::ajFeattableIsNuc;
*Bio::Emboss::Feattable::ajFeattableIsProt = *Bio::Emboss::ajFeattableIsProt;
*Bio::Emboss::Feattable::ajFeattableLen = *Bio::Emboss::ajFeattableLen;
*Bio::Emboss::Feattable::ajFeattablePos = *Bio::Emboss::ajFeattablePos;
*Bio::Emboss::Feattable::ajFeattablePosI = *Bio::Emboss::ajFeattablePosI;
*Bio::Emboss::Feattable::ajFeattableReverse = *Bio::Emboss::ajFeattableReverse;
*Bio::Emboss::Feattable::ajFeattableSetDna = *Bio::Emboss::ajFeattableSetDna;
*Bio::Emboss::Feattable::ajFeattableSetProt = *Bio::Emboss::ajFeattableSetProt;
*Bio::Emboss::Feattable::ajFeattableSetRange = *Bio::Emboss::ajFeattableSetRange;
*Bio::Emboss::Feattable::ajFeattableSize = *Bio::Emboss::ajFeattableSize;
*Bio::Emboss::Feattable::ajFeattableTrace = *Bio::Emboss::ajFeattableTrace;
*Bio::Emboss::Feattable::ajFeattableTrimOff = *Bio::Emboss::ajFeattableTrimOff;
*Bio::Emboss::Feattable::ajFeattableWrite = *Bio::Emboss::ajFeattableWrite;
*Bio::Emboss::Feattable::ajFeattableWriteDdbj = *Bio::Emboss::ajFeattableWriteDdbj;
*Bio::Emboss::Feattable::ajFeattableWriteEmbl = *Bio::Emboss::ajFeattableWriteEmbl;
*Bio::Emboss::Feattable::ajFeattableWriteGenbank = *Bio::Emboss::ajFeattableWriteGenbank;
*Bio::Emboss::Feattable::ajFeattableWriteGff = *Bio::Emboss::ajFeattableWriteGff;
*Bio::Emboss::Feattable::ajFeattableWritePir = *Bio::Emboss::ajFeattableWritePir;
*Bio::Emboss::Feattable::ajFeattableWriteSwiss = *Bio::Emboss::ajFeattableWriteSwiss;
*Bio::Emboss::Feattable::ajFeatUfoWrite = *Bio::Emboss::ajFeatUfoWrite;

*Bio::Emboss::Feature::ajFeatIsChild = *Bio::Emboss::ajFeatIsChild;
*Bio::Emboss::Feature::ajFeatCopy = *Bio::Emboss::ajFeatCopy;
*Bio::Emboss::Feature::ajFeatDel = *Bio::Emboss::ajFeatDel;
*Bio::Emboss::Feature::ajFeatGetEnd = *Bio::Emboss::ajFeatGetEnd;
*Bio::Emboss::Feature::ajFeatGetForward = *Bio::Emboss::ajFeatGetForward;
*Bio::Emboss::Feature::ajFeatGetFrame = *Bio::Emboss::ajFeatGetFrame;
*Bio::Emboss::Feature::ajFeatGetNote = *Bio::Emboss::ajFeatGetNote;
*Bio::Emboss::Feature::ajFeatGetNoteI = *Bio::Emboss::ajFeatGetNoteI;
*Bio::Emboss::Feature::ajFeatGetStart = *Bio::Emboss::ajFeatGetStart;
*Bio::Emboss::Feature::ajFeatGetTag = *Bio::Emboss::ajFeatGetTag;
*Bio::Emboss::Feature::ajFeatGetType = *Bio::Emboss::ajFeatGetType;
*Bio::Emboss::Feature::ajFeatIsCompMult = *Bio::Emboss::ajFeatIsCompMult;
*Bio::Emboss::Feature::ajFeatIsLocal = *Bio::Emboss::ajFeatIsLocal;
*Bio::Emboss::Feature::ajFeatIsLocalRange = *Bio::Emboss::ajFeatIsLocalRange;
*Bio::Emboss::Feature::ajFeatIsMultiple = *Bio::Emboss::ajFeatIsMultiple;
*Bio::Emboss::Feature::ajFeatReverse = *Bio::Emboss::ajFeatReverse;
*Bio::Emboss::Feature::ajFeatSetDesc = *Bio::Emboss::ajFeatSetDesc;
*Bio::Emboss::Feature::ajFeatSetDescApp = *Bio::Emboss::ajFeatSetDescApp;
*Bio::Emboss::Feature::ajFeatTagAdd = *Bio::Emboss::ajFeatTagAdd;
*Bio::Emboss::Feature::ajFeatTagAddC = *Bio::Emboss::ajFeatTagAddC;
*Bio::Emboss::Feature::ajFeatTagAddCC = *Bio::Emboss::ajFeatTagAddCC;
*Bio::Emboss::Feature::ajFeatTagIter = *Bio::Emboss::ajFeatTagIter;
*Bio::Emboss::Feature::ajFeatTagSet = *Bio::Emboss::ajFeatTagSet;
*Bio::Emboss::Feature::ajFeatTagSetC = *Bio::Emboss::ajFeatTagSetC;
*Bio::Emboss::Feature::ajFeatTagTrace = *Bio::Emboss::ajFeatTagTrace;
*Bio::Emboss::Feature::ajFeatTrace = *Bio::Emboss::ajFeatTrace;
*Bio::Emboss::Feature::ajFeatTrimOffRange = *Bio::Emboss::ajFeatTrimOffRange;

*Bio::Emboss::File::ajAcdPrintType = *Bio::Emboss::ajAcdPrintType;
*Bio::Emboss::File::ajAcdPrintQual = *Bio::Emboss::ajAcdPrintQual;
*Bio::Emboss::File::ajAlignPrintFormat = *Bio::Emboss::ajAlignPrintFormat;
*Bio::Emboss::File::ajDmxScophitsWrite = *Bio::Emboss::ajDmxScophitsWrite;
*Bio::Emboss::File::ajDmxScophitsWriteFasta = *Bio::Emboss::ajDmxScophitsWriteFasta;
*Bio::Emboss::File::ajDmxScophitReadFasta = *Bio::Emboss::ajDmxScophitReadFasta;
*Bio::Emboss::File::ajDmxScopalgRead = *Bio::Emboss::ajDmxScopalgRead;
*Bio::Emboss::File::ajScopReadCNew = *Bio::Emboss::ajScopReadCNew;
*Bio::Emboss::File::ajScopReadNew = *Bio::Emboss::ajScopReadNew;
*Bio::Emboss::File::ajScopReadAllNew = *Bio::Emboss::ajScopReadAllNew;
*Bio::Emboss::File::ajScopReadAllRawNew = *Bio::Emboss::ajScopReadAllRawNew;
*Bio::Emboss::File::ajScopWrite = *Bio::Emboss::ajScopWrite;
*Bio::Emboss::File::ajPdbWriteDomain = *Bio::Emboss::ajPdbWriteDomain;
*Bio::Emboss::File::ajCathReadCNew = *Bio::Emboss::ajCathReadCNew;
*Bio::Emboss::File::ajCathReadNew = *Bio::Emboss::ajCathReadNew;
*Bio::Emboss::File::ajCathReadAllNew = *Bio::Emboss::ajCathReadAllNew;
*Bio::Emboss::File::ajCathReadAllRawNew = *Bio::Emboss::ajCathReadAllRawNew;
*Bio::Emboss::File::ajCathWrite = *Bio::Emboss::ajCathWrite;
*Bio::Emboss::File::ajDomainReadNew = *Bio::Emboss::ajDomainReadNew;
*Bio::Emboss::File::ajDomainReadCNew = *Bio::Emboss::ajDomainReadCNew;
*Bio::Emboss::File::ajDomainReadAllNew = *Bio::Emboss::ajDomainReadAllNew;
*Bio::Emboss::File::ajDomainWrite = *Bio::Emboss::ajDomainWrite;
*Bio::Emboss::File::ajDomainDCFType = *Bio::Emboss::ajDomainDCFType;
*Bio::Emboss::File::ajFileBuffNewFile = *Bio::Emboss::ajFileBuffNewFile;
*Bio::Emboss::File::ajFileClose = *Bio::Emboss::ajFileClose;
*Bio::Emboss::File::ajFileEof = *Bio::Emboss::ajFileEof;
*Bio::Emboss::File::ajFileFp = *Bio::Emboss::ajFileFp;
*Bio::Emboss::File::ajFileGetName = *Bio::Emboss::ajFileGetName;
*Bio::Emboss::File::ajFileGets = *Bio::Emboss::ajFileGets;
*Bio::Emboss::File::ajFileGetsL = *Bio::Emboss::ajFileGetsL;
*Bio::Emboss::File::ajFileGetsTrim = *Bio::Emboss::ajFileGetsTrim;
*Bio::Emboss::File::ajFileGetsTrimL = *Bio::Emboss::ajFileGetsTrimL;
*Bio::Emboss::File::ajFileName = *Bio::Emboss::ajFileName;
*Bio::Emboss::File::ajFileOutHeader = *Bio::Emboss::ajFileOutHeader;
*Bio::Emboss::File::ajFileOutClose = *Bio::Emboss::ajFileOutClose;
*Bio::Emboss::File::ajFileNext = *Bio::Emboss::ajFileNext;
*Bio::Emboss::File::ajFileReadAppend = *Bio::Emboss::ajFileReadAppend;
*Bio::Emboss::File::ajFileReadLine = *Bio::Emboss::ajFileReadLine;
*Bio::Emboss::File::ajFileReadUint = *Bio::Emboss::ajFileReadUint;
*Bio::Emboss::File::ajFileReopen = *Bio::Emboss::ajFileReopen;
*Bio::Emboss::File::ajFileSeek = *Bio::Emboss::ajFileSeek;
*Bio::Emboss::File::ajFileStderr = *Bio::Emboss::ajFileStderr;
*Bio::Emboss::File::ajFileStdin = *Bio::Emboss::ajFileStdin;
*Bio::Emboss::File::ajFileStdout = *Bio::Emboss::ajFileStdout;
*Bio::Emboss::File::ajFileTell = *Bio::Emboss::ajFileTell;
*Bio::Emboss::File::ajFileTrace = *Bio::Emboss::ajFileTrace;
*Bio::Emboss::File::ajFileUnbuffer = *Bio::Emboss::ajFileUnbuffer;
*Bio::Emboss::File::ajFileWrite = *Bio::Emboss::ajFileWrite;
*Bio::Emboss::File::ajFileWriteByte = *Bio::Emboss::ajFileWriteByte;
*Bio::Emboss::File::ajFileWriteChar = *Bio::Emboss::ajFileWriteChar;
*Bio::Emboss::File::ajFileWriteInt2 = *Bio::Emboss::ajFileWriteInt2;
*Bio::Emboss::File::ajFileWriteInt4 = *Bio::Emboss::ajFileWriteInt4;
*Bio::Emboss::File::ajFileWriteInt8 = *Bio::Emboss::ajFileWriteInt8;
*Bio::Emboss::File::ajFileWriteStr = *Bio::Emboss::ajFileWriteStr;
*Bio::Emboss::File::ajGraphPrintType = *Bio::Emboss::ajGraphPrintType;
*Bio::Emboss::File::ajNamPrintDbAttr = *Bio::Emboss::ajNamPrintDbAttr;
*Bio::Emboss::File::ajNamPrintRsAttr = *Bio::Emboss::ajNamPrintRsAttr;
*Bio::Emboss::File::ajPdbReadNew = *Bio::Emboss::ajPdbReadNew;
*Bio::Emboss::File::ajPdbReadFirstModelNew = *Bio::Emboss::ajPdbReadFirstModelNew;
*Bio::Emboss::File::ajPdbWriteAll = *Bio::Emboss::ajPdbWriteAll;
*Bio::Emboss::File::ajPdbWriteSegment = *Bio::Emboss::ajPdbWriteSegment;
*Bio::Emboss::File::ajHetReadRawNew = *Bio::Emboss::ajHetReadRawNew;
*Bio::Emboss::File::ajHetReadNew = *Bio::Emboss::ajHetReadNew;
*Bio::Emboss::File::ajHetWrite = *Bio::Emboss::ajHetWrite;
*Bio::Emboss::File::ajVdwallReadNew = *Bio::Emboss::ajVdwallReadNew;
*Bio::Emboss::File::ajCmapReadCNew = *Bio::Emboss::ajCmapReadCNew;
*Bio::Emboss::File::ajCmapReadINew = *Bio::Emboss::ajCmapReadINew;
*Bio::Emboss::File::ajCmapReadNew = *Bio::Emboss::ajCmapReadNew;
*Bio::Emboss::File::ajCmapReadAllNew = *Bio::Emboss::ajCmapReadAllNew;
*Bio::Emboss::File::ajCmapWrite = *Bio::Emboss::ajCmapWrite;
*Bio::Emboss::File::ajPdbtospReadAllRawNew = *Bio::Emboss::ajPdbtospReadAllRawNew;
*Bio::Emboss::File::ajPdbtospReadNew = *Bio::Emboss::ajPdbtospReadNew;
*Bio::Emboss::File::ajPdbtospReadCNew = *Bio::Emboss::ajPdbtospReadCNew;
*Bio::Emboss::File::ajPdbtospReadAllNew = *Bio::Emboss::ajPdbtospReadAllNew;
*Bio::Emboss::File::ajPdbtospWrite = *Bio::Emboss::ajPdbtospWrite;
*Bio::Emboss::File::ajPdbReadRawNew = *Bio::Emboss::ajPdbReadRawNew;
*Bio::Emboss::File::ajReportPrintFormat = *Bio::Emboss::ajReportPrintFormat;
*Bio::Emboss::File::ajSeqABIGetBaseOffset = *Bio::Emboss::ajSeqABIGetBaseOffset;
*Bio::Emboss::File::ajSeqABIGetBasePosition = *Bio::Emboss::ajSeqABIGetBasePosition;
*Bio::Emboss::File::ajSeqABIGetBasePosOffset = *Bio::Emboss::ajSeqABIGetBasePosOffset;
*Bio::Emboss::File::ajSeqABIGetBaseSpace = *Bio::Emboss::ajSeqABIGetBaseSpace;
*Bio::Emboss::File::ajSeqABIGetData = *Bio::Emboss::ajSeqABIGetData;
*Bio::Emboss::File::ajSeqABIGetFWO = *Bio::Emboss::ajSeqABIGetFWO;
*Bio::Emboss::File::ajSeqABIGetNBase = *Bio::Emboss::ajSeqABIGetNBase;
*Bio::Emboss::File::ajSeqABIGetNData = *Bio::Emboss::ajSeqABIGetNData;
*Bio::Emboss::File::ajSeqABIGetPrimerOffset = *Bio::Emboss::ajSeqABIGetPrimerOffset;
*Bio::Emboss::File::ajSeqABIGetPrimerPosition = *Bio::Emboss::ajSeqABIGetPrimerPosition;
*Bio::Emboss::File::ajSeqABIGetSignal = *Bio::Emboss::ajSeqABIGetSignal;
*Bio::Emboss::File::ajSeqABIGetTraceOffset = *Bio::Emboss::ajSeqABIGetTraceOffset;
*Bio::Emboss::File::ajSeqABIMachineName = *Bio::Emboss::ajSeqABIMachineName;
*Bio::Emboss::File::ajSeqABIReadSeq = *Bio::Emboss::ajSeqABIReadSeq;
*Bio::Emboss::File::ajSeqABISampleName = *Bio::Emboss::ajSeqABISampleName;
*Bio::Emboss::File::ajSeqABITest = *Bio::Emboss::ajSeqABITest;
*Bio::Emboss::File::ajSeqPrintAccess = *Bio::Emboss::ajSeqPrintAccess;
*Bio::Emboss::File::ajSeqPrintInFormat = *Bio::Emboss::ajSeqPrintInFormat;
*Bio::Emboss::File::ajSeqPrintType = *Bio::Emboss::ajSeqPrintType;
*Bio::Emboss::File::ajSeqoutNewF = *Bio::Emboss::ajSeqoutNewF;
*Bio::Emboss::File::ajSeqPrintOutFormat = *Bio::Emboss::ajSeqPrintOutFormat;
*Bio::Emboss::File::ajSeqWriteXyz = *Bio::Emboss::ajSeqWriteXyz;
*Bio::Emboss::File::ajSssWriteXyz = *Bio::Emboss::ajSssWriteXyz;
*Bio::Emboss::File::ajXyzPdbtospRead = *Bio::Emboss::ajXyzPdbtospRead;
*Bio::Emboss::File::ajXyzPdbtospReadC = *Bio::Emboss::ajXyzPdbtospReadC;
*Bio::Emboss::File::ajXyzPdbtospReadAll = *Bio::Emboss::ajXyzPdbtospReadAll;
*Bio::Emboss::File::ajXyzPdbWriteAll = *Bio::Emboss::ajXyzPdbWriteAll;
*Bio::Emboss::File::ajXyzPdbWriteDomain = *Bio::Emboss::ajXyzPdbWriteDomain;
*Bio::Emboss::File::ajXyzCpdbRead = *Bio::Emboss::ajXyzCpdbRead;
*Bio::Emboss::File::ajXyzCpdbReadFirstModel = *Bio::Emboss::ajXyzCpdbReadFirstModel;
*Bio::Emboss::File::ajXyzCpdbReadOld = *Bio::Emboss::ajXyzCpdbReadOld;
*Bio::Emboss::File::ajXyzCpdbWriteAll = *Bio::Emboss::ajXyzCpdbWriteAll;
*Bio::Emboss::File::ajXyzCpdbWriteDomain = *Bio::Emboss::ajXyzCpdbWriteDomain;
*Bio::Emboss::File::ajXyzScopRead = *Bio::Emboss::ajXyzScopRead;
*Bio::Emboss::File::ajXyzScopReadC = *Bio::Emboss::ajXyzScopReadC;
*Bio::Emboss::File::ajXyzScopReadAll = *Bio::Emboss::ajXyzScopReadAll;
*Bio::Emboss::File::ajXyzScopWrite = *Bio::Emboss::ajXyzScopWrite;
*Bio::Emboss::File::ajXyzScopclaRead = *Bio::Emboss::ajXyzScopclaRead;
*Bio::Emboss::File::ajXyzScopclaReadC = *Bio::Emboss::ajXyzScopclaReadC;
*Bio::Emboss::File::ajXyzScopdesRead = *Bio::Emboss::ajXyzScopdesRead;
*Bio::Emboss::File::ajXyzScopdesReadC = *Bio::Emboss::ajXyzScopdesReadC;
*Bio::Emboss::File::ajXyzHitlistRead = *Bio::Emboss::ajXyzHitlistRead;
*Bio::Emboss::File::ajXyzHitlistReadNode = *Bio::Emboss::ajXyzHitlistReadNode;
*Bio::Emboss::File::ajXyzHitlistReadFam = *Bio::Emboss::ajXyzHitlistReadFam;
*Bio::Emboss::File::ajXyzHitlistReadSfam = *Bio::Emboss::ajXyzHitlistReadSfam;
*Bio::Emboss::File::ajXyzHitlistReadFold = *Bio::Emboss::ajXyzHitlistReadFold;
*Bio::Emboss::File::ajXyzHitlistWrite = *Bio::Emboss::ajXyzHitlistWrite;
*Bio::Emboss::File::ajXyzPrintPdbSeqresChain = *Bio::Emboss::ajXyzPrintPdbSeqresChain;
*Bio::Emboss::File::ajXyzPrintPdbSeqresDomain = *Bio::Emboss::ajXyzPrintPdbSeqresDomain;
*Bio::Emboss::File::ajXyzPrintPdbAtomChain = *Bio::Emboss::ajXyzPrintPdbAtomChain;
*Bio::Emboss::File::ajXyzPrintPdbAtomDomain = *Bio::Emboss::ajXyzPrintPdbAtomDomain;
*Bio::Emboss::File::ajXyzPrintPdbHeterogen = *Bio::Emboss::ajXyzPrintPdbHeterogen;
*Bio::Emboss::File::ajXyzPrintPdbText = *Bio::Emboss::ajXyzPrintPdbText;
*Bio::Emboss::File::ajXyzPrintPdbHeader = *Bio::Emboss::ajXyzPrintPdbHeader;
*Bio::Emboss::File::ajXyzPrintPdbHeaderScop = *Bio::Emboss::ajXyzPrintPdbHeaderScop;
*Bio::Emboss::File::ajXyzPrintPdbTitle = *Bio::Emboss::ajXyzPrintPdbTitle;
*Bio::Emboss::File::ajXyzPrintPdbCompnd = *Bio::Emboss::ajXyzPrintPdbCompnd;
*Bio::Emboss::File::ajXyzPrintPdbSource = *Bio::Emboss::ajXyzPrintPdbSource;
*Bio::Emboss::File::ajXyzPrintPdbEmptyRemark = *Bio::Emboss::ajXyzPrintPdbEmptyRemark;
*Bio::Emboss::File::ajXyzPrintPdbResolution = *Bio::Emboss::ajXyzPrintPdbResolution;
*Bio::Emboss::File::ajXyzScopalgRead = *Bio::Emboss::ajXyzScopalgRead;
*Bio::Emboss::File::ajXyzScopalgWrite = *Bio::Emboss::ajXyzScopalgWrite;
*Bio::Emboss::File::ajXyzCmapRead = *Bio::Emboss::ajXyzCmapRead;
*Bio::Emboss::File::ajXyzCmapReadC = *Bio::Emboss::ajXyzCmapReadC;
*Bio::Emboss::File::ajXyzCmapReadI = *Bio::Emboss::ajXyzCmapReadI;
*Bio::Emboss::File::ajXyzVdwallRead = *Bio::Emboss::ajXyzVdwallRead;
*Bio::Emboss::File::ajXyzSignatureRead = *Bio::Emboss::ajXyzSignatureRead;
*Bio::Emboss::File::ajXyzSignatureWrite = *Bio::Emboss::ajXyzSignatureWrite;
*Bio::Emboss::File::ajXyzSignatureHitsWrite = *Bio::Emboss::ajXyzSignatureHitsWrite;
*Bio::Emboss::File::ajXyzSignatureAlignWrite = *Bio::Emboss::ajXyzSignatureAlignWrite;
*Bio::Emboss::File::ajXyzHetRawRead = *Bio::Emboss::ajXyzHetRawRead;
*Bio::Emboss::File::ajXyzHetRead = *Bio::Emboss::ajXyzHetRead;
*Bio::Emboss::File::ajXyzHetWrite = *Bio::Emboss::ajXyzHetWrite;
*Bio::Emboss::File::embComWriteValueOfSeq = *Bio::Emboss::embComWriteValueOfSeq;
*Bio::Emboss::File::embComWriteFile = *Bio::Emboss::embComWriteFile;
*Bio::Emboss::File::embDbiHeaderSize = *Bio::Emboss::embDbiHeaderSize;
*Bio::Emboss::File::embDbiSortClose = *Bio::Emboss::embDbiSortClose;
*Bio::Emboss::File::embDbiSortWriteEntry = *Bio::Emboss::embDbiSortWriteEntry;
*Bio::Emboss::File::embDbiWriteDivisionRecord = *Bio::Emboss::embDbiWriteDivisionRecord;
*Bio::Emboss::File::embDbiWriteEntryRecord = *Bio::Emboss::embDbiWriteEntryRecord;
*Bio::Emboss::File::embDbiWriteHit = *Bio::Emboss::embDbiWriteHit;
*Bio::Emboss::File::embDbiWriteTrg = *Bio::Emboss::embDbiWriteTrg;
*Bio::Emboss::File::embEstOutBlastStyle = *Bio::Emboss::embEstOutBlastStyle;
*Bio::Emboss::File::embEstPrintAlign = *Bio::Emboss::embEstPrintAlign;
*Bio::Emboss::File::embGrpOutputGroupsList = *Bio::Emboss::embGrpOutputGroupsList;
*Bio::Emboss::File::embGrpOutputProgsList = *Bio::Emboss::embGrpOutputProgsList;
*Bio::Emboss::File::embMatPrintsInit = *Bio::Emboss::embMatPrintsInit;
*Bio::Emboss::File::embMatProtReadInt = *Bio::Emboss::embMatProtReadInt;
*Bio::Emboss::File::embPropAminoRead = *Bio::Emboss::embPropAminoRead;
*Bio::Emboss::File::embShowPrint = *Bio::Emboss::embShowPrint;
*Bio::Emboss::File::embWordMatchListPrint = *Bio::Emboss::embWordMatchListPrint;

*Bio::Emboss::FileBuff::ajFileBuffBuff = *Bio::Emboss::ajFileBuffBuff;
*Bio::Emboss::FileBuff::ajFileBuffClear = *Bio::Emboss::ajFileBuffClear;
*Bio::Emboss::FileBuff::ajFileBuffClearStore = *Bio::Emboss::ajFileBuffClearStore;
*Bio::Emboss::FileBuff::ajFileBuffDel = *Bio::Emboss::ajFileBuffDel;
*Bio::Emboss::FileBuff::ajFileBuffEmpty = *Bio::Emboss::ajFileBuffEmpty;
*Bio::Emboss::FileBuff::ajFileBuffEnd = *Bio::Emboss::ajFileBuffEnd;
*Bio::Emboss::FileBuff::ajFileBuffEof = *Bio::Emboss::ajFileBuffEof;
*Bio::Emboss::FileBuff::ajFileBuffFile = *Bio::Emboss::ajFileBuffFile;
*Bio::Emboss::FileBuff::ajFileBuffFix = *Bio::Emboss::ajFileBuffFix;
*Bio::Emboss::FileBuff::ajFileBuffFp = *Bio::Emboss::ajFileBuffFp;
*Bio::Emboss::FileBuff::ajFileBuffFreeClear = *Bio::Emboss::ajFileBuffFreeClear;
*Bio::Emboss::FileBuff::ajFileBuffGet = *Bio::Emboss::ajFileBuffGet;
*Bio::Emboss::FileBuff::ajFileBuffGetL = *Bio::Emboss::ajFileBuffGetL;
*Bio::Emboss::FileBuff::ajFileBuffGetStore = *Bio::Emboss::ajFileBuffGetStore;
*Bio::Emboss::FileBuff::ajFileBuffGetStoreL = *Bio::Emboss::ajFileBuffGetStoreL;
*Bio::Emboss::FileBuff::ajFileBuffIsBuffered = *Bio::Emboss::ajFileBuffIsBuffered;
*Bio::Emboss::FileBuff::ajFileBuffLoad = *Bio::Emboss::ajFileBuffLoad;
*Bio::Emboss::FileBuff::ajFileBuffLoadC = *Bio::Emboss::ajFileBuffLoadC;
*Bio::Emboss::FileBuff::ajFileBuffLoadS = *Bio::Emboss::ajFileBuffLoadS;
*Bio::Emboss::FileBuff::ajFileBuffNobuff = *Bio::Emboss::ajFileBuffNobuff;
*Bio::Emboss::FileBuff::ajFileBuffPrint = *Bio::Emboss::ajFileBuffPrint;
*Bio::Emboss::FileBuff::ajFileBuffReset = *Bio::Emboss::ajFileBuffReset;
*Bio::Emboss::FileBuff::ajFileBuffResetPos = *Bio::Emboss::ajFileBuffResetPos;
*Bio::Emboss::FileBuff::ajFileBuffResetStore = *Bio::Emboss::ajFileBuffResetStore;
*Bio::Emboss::FileBuff::ajFileBuffSetFile = *Bio::Emboss::ajFileBuffSetFile;
*Bio::Emboss::FileBuff::ajFileBuffStripHtml = *Bio::Emboss::ajFileBuffStripHtml;
*Bio::Emboss::FileBuff::ajFileBuffStripHtmlPre = *Bio::Emboss::ajFileBuffStripHtmlPre;
*Bio::Emboss::FileBuff::ajFileBuffTrace = *Bio::Emboss::ajFileBuffTrace;
*Bio::Emboss::FileBuff::ajFileBuffTraceFull = *Bio::Emboss::ajFileBuffTraceFull;
*Bio::Emboss::FileBuff::ajNexusParse = *Bio::Emboss::ajNexusParse;

*Bio::Emboss::Graph::ajGraphClear = *Bio::Emboss::ajGraphClear;
*Bio::Emboss::Graph::ajGraphGetSubTitle = *Bio::Emboss::ajGraphGetSubTitle;
*Bio::Emboss::Graph::ajGraphGetSubTitleC = *Bio::Emboss::ajGraphGetSubTitleC;
*Bio::Emboss::Graph::ajGraphGetTitle = *Bio::Emboss::ajGraphGetTitle;
*Bio::Emboss::Graph::ajGraphGetTitleC = *Bio::Emboss::ajGraphGetTitleC;
*Bio::Emboss::Graph::ajGraphGetXTitle = *Bio::Emboss::ajGraphGetXTitle;
*Bio::Emboss::Graph::ajGraphGetXTitleC = *Bio::Emboss::ajGraphGetXTitleC;
*Bio::Emboss::Graph::ajGraphGetYTitle = *Bio::Emboss::ajGraphGetYTitle;
*Bio::Emboss::Graph::ajGraphGetYTitleC = *Bio::Emboss::ajGraphGetYTitleC;
*Bio::Emboss::Graph::ajGraphInitSeq = *Bio::Emboss::ajGraphInitSeq;
*Bio::Emboss::Graph::ajGraphIsData = *Bio::Emboss::ajGraphIsData;
*Bio::Emboss::Graph::ajGraphAddLine = *Bio::Emboss::ajGraphAddLine;
*Bio::Emboss::Graph::ajGraphAddRect = *Bio::Emboss::ajGraphAddRect;
*Bio::Emboss::Graph::ajGraphAddText = *Bio::Emboss::ajGraphAddText;
*Bio::Emboss::Graph::ajGraphOpen = *Bio::Emboss::ajGraphOpen;
*Bio::Emboss::Graph::ajGraphOpenPlot = *Bio::Emboss::ajGraphOpenPlot;
*Bio::Emboss::Graph::ajGraphOpenWin = *Bio::Emboss::ajGraphOpenWin;
*Bio::Emboss::Graph::ajGraphSet = *Bio::Emboss::ajGraphSet;
*Bio::Emboss::Graph::ajGraphSetDevice = *Bio::Emboss::ajGraphSetDevice;
*Bio::Emboss::Graph::ajGraphSetMulti = *Bio::Emboss::ajGraphSetMulti;
*Bio::Emboss::Graph::ajGraphSetName = *Bio::Emboss::ajGraphSetName;
*Bio::Emboss::Graph::ajGraphTrace = *Bio::Emboss::ajGraphTrace;
*Bio::Emboss::Graph::ajGraphTraceInt = *Bio::Emboss::ajGraphTraceInt;
*Bio::Emboss::Graph::ajGraphDataAdd = *Bio::Emboss::ajGraphDataAdd;
*Bio::Emboss::Graph::ajGraphDataReplace = *Bio::Emboss::ajGraphDataReplace;
*Bio::Emboss::Graph::ajGraphxyDel = *Bio::Emboss::ajGraphxyDel;
*Bio::Emboss::Graph::ajGraphxyDisplay = *Bio::Emboss::ajGraphxyDisplay;
*Bio::Emboss::Graph::ajGraphxyCheckMaxMin = *Bio::Emboss::ajGraphxyCheckMaxMin;
*Bio::Emboss::Graph::ajGraphxySet = *Bio::Emboss::ajGraphxySet;
*Bio::Emboss::Graph::ajGraphxySetCirclePoints = *Bio::Emboss::ajGraphxySetCirclePoints;
*Bio::Emboss::Graph::ajGraphSetFlag = *Bio::Emboss::ajGraphSetFlag;
*Bio::Emboss::Graph::ajGraphxySetGaps = *Bio::Emboss::ajGraphxySetGaps;
*Bio::Emboss::Graph::ajGraphxySetJoinPoints = *Bio::Emboss::ajGraphxySetJoinPoints;
*Bio::Emboss::Graph::ajGraphxySetMaxMin = *Bio::Emboss::ajGraphxySetMaxMin;
*Bio::Emboss::Graph::ajGraphSetOut = *Bio::Emboss::ajGraphSetOut;
*Bio::Emboss::Graph::ajGraphSetOutC = *Bio::Emboss::ajGraphSetOutC;
*Bio::Emboss::Graph::ajGraphxySetOverLap = *Bio::Emboss::ajGraphxySetOverLap;
*Bio::Emboss::Graph::ajGraphSetSubTitleDo = *Bio::Emboss::ajGraphSetSubTitleDo;
*Bio::Emboss::Graph::ajGraphSetTitleDo = *Bio::Emboss::ajGraphSetTitleDo;
*Bio::Emboss::Graph::ajGraphxySetXBottom = *Bio::Emboss::ajGraphxySetXBottom;
*Bio::Emboss::Graph::ajGraphxySetXLabelTop = *Bio::Emboss::ajGraphxySetXLabelTop;
*Bio::Emboss::Graph::ajGraphxySetXTick = *Bio::Emboss::ajGraphxySetXTick;
*Bio::Emboss::Graph::ajGraphxySetXTop = *Bio::Emboss::ajGraphxySetXTop;
*Bio::Emboss::Graph::ajGraphxySetXEnd = *Bio::Emboss::ajGraphxySetXEnd;
*Bio::Emboss::Graph::ajGraphxySetXGrid = *Bio::Emboss::ajGraphxySetXGrid;
*Bio::Emboss::Graph::ajGraphxySetXInvTicks = *Bio::Emboss::ajGraphxySetXInvTicks;
*Bio::Emboss::Graph::ajGraphxySetXLabel = *Bio::Emboss::ajGraphxySetXLabel;
*Bio::Emboss::Graph::ajGraphxySetXRangeII = *Bio::Emboss::ajGraphxySetXRangeII;
*Bio::Emboss::Graph::ajGraphxySetXStart = *Bio::Emboss::ajGraphxySetXStart;
*Bio::Emboss::Graph::ajGraphxySetYLabelLeft = *Bio::Emboss::ajGraphxySetYLabelLeft;
*Bio::Emboss::Graph::ajGraphxySetYLeft = *Bio::Emboss::ajGraphxySetYLeft;
*Bio::Emboss::Graph::ajGraphxySetYRight = *Bio::Emboss::ajGraphxySetYRight;
*Bio::Emboss::Graph::ajGraphxySetYTick = *Bio::Emboss::ajGraphxySetYTick;
*Bio::Emboss::Graph::ajGraphxySetYEnd = *Bio::Emboss::ajGraphxySetYEnd;
*Bio::Emboss::Graph::ajGraphxySetYGrid = *Bio::Emboss::ajGraphxySetYGrid;
*Bio::Emboss::Graph::ajGraphxySetYInvTicks = *Bio::Emboss::ajGraphxySetYInvTicks;
*Bio::Emboss::Graph::ajGraphxySetYLabel = *Bio::Emboss::ajGraphxySetYLabel;
*Bio::Emboss::Graph::ajGraphxySetYRangeII = *Bio::Emboss::ajGraphxySetYRangeII;
*Bio::Emboss::Graph::ajGraphxySetYStart = *Bio::Emboss::ajGraphxySetYStart;
*Bio::Emboss::Graph::ajGraphSetSubTitle = *Bio::Emboss::ajGraphSetSubTitle;
*Bio::Emboss::Graph::ajGraphSetSubTitleC = *Bio::Emboss::ajGraphSetSubTitleC;
*Bio::Emboss::Graph::ajGraphSetTitle = *Bio::Emboss::ajGraphSetTitle;
*Bio::Emboss::Graph::ajGraphSetTitleC = *Bio::Emboss::ajGraphSetTitleC;
*Bio::Emboss::Graph::ajGraphSetXTitle = *Bio::Emboss::ajGraphSetXTitle;
*Bio::Emboss::Graph::ajGraphSetXTitleC = *Bio::Emboss::ajGraphSetXTitleC;
*Bio::Emboss::Graph::ajGraphSetYTitle = *Bio::Emboss::ajGraphSetYTitle;
*Bio::Emboss::Graph::ajGraphSetYTitleC = *Bio::Emboss::ajGraphSetYTitleC;

*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddLine = *Bio::Emboss::ajGraphPlpDataAddLine;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddRect = *Bio::Emboss::ajGraphPlpDataAddRect;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddText = *Bio::Emboss::ajGraphPlpDataAddText;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxMin = *Bio::Emboss::ajGraphPlpDataSetMaxMin;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxima = *Bio::Emboss::ajGraphPlpDataSetMaxima;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTypeC = *Bio::Emboss::ajGraphPlpDataSetTypeC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataTrace = *Bio::Emboss::ajGraphPlpDataTrace;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataDel = *Bio::Emboss::ajGraphPlpDataDel;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataCalcXY = *Bio::Emboss::ajGraphPlpDataCalcXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXY = *Bio::Emboss::ajGraphPlpDataSetXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitle = *Bio::Emboss::ajGraphPlpDataSetSubTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitleC = *Bio::Emboss::ajGraphPlpDataSetSubTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitle = *Bio::Emboss::ajGraphPlpDataSetTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitleC = *Bio::Emboss::ajGraphPlpDataSetTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitle = *Bio::Emboss::ajGraphPlpDataSetXTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitleC = *Bio::Emboss::ajGraphPlpDataSetXTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitle = *Bio::Emboss::ajGraphPlpDataSetYTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitleC = *Bio::Emboss::ajGraphPlpDataSetYTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetColour = *Bio::Emboss::ajGraphPlpDataSetColour;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetLineType = *Bio::Emboss::ajGraphPlpDataSetLineType;

*Bio::Emboss::Het::ajHetDel = *Bio::Emboss::ajHetDel;
*Bio::Emboss::Het::ajXyzHetDel = *Bio::Emboss::ajXyzHetDel;

*Bio::Emboss::Hetent::ajHetentDel = *Bio::Emboss::ajHetentDel;
*Bio::Emboss::Hetent::ajXyzHetentDel = *Bio::Emboss::ajXyzHetentDel;

*Bio::Emboss::Hist::ajHistCopyData = *Bio::Emboss::ajHistCopyData;
*Bio::Emboss::Hist::ajHistDelete = *Bio::Emboss::ajHistDelete;
*Bio::Emboss::Hist::ajHistDisplay = *Bio::Emboss::ajHistDisplay;
*Bio::Emboss::Hist::ajHistSetBlackandWhite = *Bio::Emboss::ajHistSetBlackandWhite;
*Bio::Emboss::Hist::ajHistSetColour = *Bio::Emboss::ajHistSetColour;
*Bio::Emboss::Hist::ajHistSetMultiTitle = *Bio::Emboss::ajHistSetMultiTitle;
*Bio::Emboss::Hist::ajHistSetMultiTitleC = *Bio::Emboss::ajHistSetMultiTitleC;
*Bio::Emboss::Hist::ajHistSetMultiXTitle = *Bio::Emboss::ajHistSetMultiXTitle;
*Bio::Emboss::Hist::ajHistSetMultiXTitleC = *Bio::Emboss::ajHistSetMultiXTitleC;
*Bio::Emboss::Hist::ajHistSetMultiYTitle = *Bio::Emboss::ajHistSetMultiYTitle;
*Bio::Emboss::Hist::ajHistSetMultiYTitleC = *Bio::Emboss::ajHistSetMultiYTitleC;
*Bio::Emboss::Hist::ajHistSetPattern = *Bio::Emboss::ajHistSetPattern;
*Bio::Emboss::Hist::ajHistSetPtrToData = *Bio::Emboss::ajHistSetPtrToData;
*Bio::Emboss::Hist::ajHistSetTitleC = *Bio::Emboss::ajHistSetTitleC;
*Bio::Emboss::Hist::ajHistSetXAxisC = *Bio::Emboss::ajHistSetXAxisC;
*Bio::Emboss::Hist::ajHistSetYAxisLeftC = *Bio::Emboss::ajHistSetYAxisLeftC;
*Bio::Emboss::Hist::ajHistSetYAxisRightC = *Bio::Emboss::ajHistSetYAxisRightC;

*Bio::Emboss::Hit::ajXyzScophitToHit = *Bio::Emboss::ajXyzScophitToHit;
*Bio::Emboss::Hit::ajXyzHitDel = *Bio::Emboss::ajXyzHitDel;
*Bio::Emboss::Hit::ajXyzHitsOverlap = *Bio::Emboss::ajXyzHitsOverlap;
*Bio::Emboss::Hit::embDmxScophitToHit = *Bio::Emboss::embDmxScophitToHit;

*Bio::Emboss::Hitidx::ajXyzHitidxDel = *Bio::Emboss::ajXyzHitidxDel;

*Bio::Emboss::Hitlist::ajXyzHitlistDel = *Bio::Emboss::ajXyzHitlistDel;
*Bio::Emboss::Hitlist::ajXyzHitlistClassify = *Bio::Emboss::ajXyzHitlistClassify;
*Bio::Emboss::Hitlist::ajXyzHitlistPriorityHigh = *Bio::Emboss::ajXyzHitlistPriorityHigh;
*Bio::Emboss::Hitlist::ajXyzHitlistPriorityLow = *Bio::Emboss::ajXyzHitlistPriorityLow;

*Bio::Emboss::List::ajDmxScophitListCopy = *Bio::Emboss::ajDmxScophitListCopy;
*Bio::Emboss::List::ajFileBuffNewInList = *Bio::Emboss::ajFileBuffNewInList;
*Bio::Emboss::List::ajFileNewInList = *Bio::Emboss::ajFileNewInList;
*Bio::Emboss::List::ajGraphInfo = *Bio::Emboss::ajGraphInfo;
*Bio::Emboss::List::ajListAppend = *Bio::Emboss::ajListAppend;
*Bio::Emboss::List::ajListCopy = *Bio::Emboss::ajListCopy;
*Bio::Emboss::List::ajListDel = *Bio::Emboss::ajListDel;
*Bio::Emboss::List::ajListFree = *Bio::Emboss::ajListFree;
*Bio::Emboss::List::ajListIter = *Bio::Emboss::ajListIter;
*Bio::Emboss::List::ajListIterBack = *Bio::Emboss::ajListIterBack;
*Bio::Emboss::List::ajListIterBackRead = *Bio::Emboss::ajListIterBackRead;
*Bio::Emboss::List::ajListIterRead = *Bio::Emboss::ajListIterRead;
*Bio::Emboss::List::ajListLength = *Bio::Emboss::ajListLength;
*Bio::Emboss::List::ajListPush = *Bio::Emboss::ajListPush;
*Bio::Emboss::List::ajListPushApp = *Bio::Emboss::ajListPushApp;
*Bio::Emboss::List::ajListReverse = *Bio::Emboss::ajListReverse;
*Bio::Emboss::List::ajListstrCopy = *Bio::Emboss::ajListstrCopy;
*Bio::Emboss::List::ajListstrDel = *Bio::Emboss::ajListstrDel;
*Bio::Emboss::List::ajListstrFree = *Bio::Emboss::ajListstrFree;
*Bio::Emboss::List::ajListstrLength = *Bio::Emboss::ajListstrLength;
*Bio::Emboss::List::ajListstrPeek = *Bio::Emboss::ajListstrPeek;
*Bio::Emboss::List::ajListstrPop = *Bio::Emboss::ajListstrPop;
*Bio::Emboss::List::ajListstrPopEnd = *Bio::Emboss::ajListstrPopEnd;
*Bio::Emboss::List::ajListstrPush = *Bio::Emboss::ajListstrPush;
*Bio::Emboss::List::ajListstrPushApp = *Bio::Emboss::ajListstrPushApp;
*Bio::Emboss::List::ajListstrReverse = *Bio::Emboss::ajListstrReverse;
*Bio::Emboss::List::ajListstrToArray = *Bio::Emboss::ajListstrToArray;
*Bio::Emboss::List::ajListstrToArrayApp = *Bio::Emboss::ajListstrToArrayApp;
*Bio::Emboss::List::ajListstrTrace = *Bio::Emboss::ajListstrTrace;
*Bio::Emboss::List::ajListTrace = *Bio::Emboss::ajListTrace;
*Bio::Emboss::List::ajListPushList = *Bio::Emboss::ajListPushList;
*Bio::Emboss::List::ajListstrPushList = *Bio::Emboss::ajListstrPushList;
*Bio::Emboss::List::ajListstrClone = *Bio::Emboss::ajListstrClone;
*Bio::Emboss::List::ajNamListListDatabases = *Bio::Emboss::ajNamListListDatabases;
*Bio::Emboss::List::ajNamListListResources = *Bio::Emboss::ajNamListListResources;
*Bio::Emboss::List::ajAtomListCopy = *Bio::Emboss::ajAtomListCopy;
*Bio::Emboss::List::ajSeqsetallRead = *Bio::Emboss::ajSeqsetallRead;
*Bio::Emboss::List::ajXyzScophitsToHitlist = *Bio::Emboss::ajXyzScophitsToHitlist;
*Bio::Emboss::List::ajXyzScophitListCopy = *Bio::Emboss::ajXyzScophitListCopy;
*Bio::Emboss::List::ajXyzScophitMergeInsertThis = *Bio::Emboss::ajXyzScophitMergeInsertThis;
*Bio::Emboss::List::ajXyzScophitMergeInsertOther = *Bio::Emboss::ajXyzScophitMergeInsertOther;
*Bio::Emboss::List::ajXyzHitlistToScophits = *Bio::Emboss::ajXyzHitlistToScophits;
*Bio::Emboss::List::ajXyzHitlistToThreeScophits = *Bio::Emboss::ajXyzHitlistToThreeScophits;
*Bio::Emboss::List::ajXyzHitlistsWriteFasta = *Bio::Emboss::ajXyzHitlistsWriteFasta;
*Bio::Emboss::List::embDataListDel = *Bio::Emboss::embDataListDel;
*Bio::Emboss::List::embDataListGetTable = *Bio::Emboss::embDataListGetTable;
*Bio::Emboss::List::embDataListGetTables = *Bio::Emboss::embDataListGetTables;
*Bio::Emboss::List::embDataListRead = *Bio::Emboss::embDataListRead;
*Bio::Emboss::List::embDbiMemEntry = *Bio::Emboss::embDbiMemEntry;
*Bio::Emboss::List::embDmxHitlistToScophits = *Bio::Emboss::embDmxHitlistToScophits;
*Bio::Emboss::List::embDmxScophitsToHitlist = *Bio::Emboss::embDmxScophitsToHitlist;
*Bio::Emboss::List::embDmxScophitsAccToHitlist = *Bio::Emboss::embDmxScophitsAccToHitlist;
*Bio::Emboss::List::embDmxScophitMergeInsertThis = *Bio::Emboss::embDmxScophitMergeInsertThis;
*Bio::Emboss::List::embDmxScophitMergeInsertThisTarget = *Bio::Emboss::embDmxScophitMergeInsertThisTarget;
*Bio::Emboss::List::embDmxScophitMergeInsertThisTargetBoth = *Bio::Emboss::embDmxScophitMergeInsertThisTargetBoth;
*Bio::Emboss::List::embDmxScophitMergeInsertOther = *Bio::Emboss::embDmxScophitMergeInsertOther;
*Bio::Emboss::List::embDmxScophitMergeInsertOtherTargetBoth = *Bio::Emboss::embDmxScophitMergeInsertOtherTargetBoth;
*Bio::Emboss::List::embDmxScophitMergeInsertOtherTarget = *Bio::Emboss::embDmxScophitMergeInsertOtherTarget;
*Bio::Emboss::List::embDmxSeqNR = *Bio::Emboss::embDmxSeqNR;
*Bio::Emboss::List::embDmxSeqNRRange = *Bio::Emboss::embDmxSeqNRRange;
*Bio::Emboss::List::embDmxSeqCompall = *Bio::Emboss::embDmxSeqCompall;
*Bio::Emboss::List::embGrpGroupsListDel = *Bio::Emboss::embGrpGroupsListDel;
*Bio::Emboss::List::embGrpKeySearchProgs = *Bio::Emboss::embGrpKeySearchProgs;
*Bio::Emboss::List::embGrpKeySearchSeeAlso = *Bio::Emboss::embGrpKeySearchSeeAlso;
*Bio::Emboss::List::embGrpSortGroupsList = *Bio::Emboss::embGrpSortGroupsList;
*Bio::Emboss::List::embGrpMakeUnique = *Bio::Emboss::embGrpMakeUnique;
*Bio::Emboss::List::embWordMatchListDelete = *Bio::Emboss::embWordMatchListDelete;
*Bio::Emboss::List::embWordMatchListConvToFeat = *Bio::Emboss::embWordMatchListConvToFeat;
*Bio::Emboss::List::embWordMatchMin = *Bio::Emboss::embWordMatchMin;

*Bio::Emboss::Matrix::ajMatrixChar = *Bio::Emboss::ajMatrixChar;
*Bio::Emboss::Matrix::ajMatrixCvt = *Bio::Emboss::ajMatrixCvt;
*Bio::Emboss::Matrix::ajMatrixDel = *Bio::Emboss::ajMatrixDel;
*Bio::Emboss::Matrix::ajMatrixName = *Bio::Emboss::ajMatrixName;
*Bio::Emboss::Matrix::ajMatrixSeqNum = *Bio::Emboss::ajMatrixSeqNum;
*Bio::Emboss::Matrix::ajMatrixRead = *Bio::Emboss::ajMatrixRead;
*Bio::Emboss::Matrix::ajMatrixSize = *Bio::Emboss::ajMatrixSize;

*Bio::Emboss::Matrixf::ajMatrixfChar = *Bio::Emboss::ajMatrixfChar;
*Bio::Emboss::Matrixf::ajMatrixfCvt = *Bio::Emboss::ajMatrixfCvt;
*Bio::Emboss::Matrixf::ajMatrixfDel = *Bio::Emboss::ajMatrixfDel;
*Bio::Emboss::Matrixf::ajMatrixfName = *Bio::Emboss::ajMatrixfName;
*Bio::Emboss::Matrixf::ajMatrixfSeqNum = *Bio::Emboss::ajMatrixfSeqNum;
*Bio::Emboss::Matrixf::ajMatrixfRead = *Bio::Emboss::ajMatrixfRead;
*Bio::Emboss::Matrixf::ajMatrixfSize = *Bio::Emboss::ajMatrixfSize;

*Bio::Emboss::Nexus::ajNexusDel = *Bio::Emboss::ajNexusDel;
*Bio::Emboss::Nexus::ajNexusGetNtaxa = *Bio::Emboss::ajNexusGetNtaxa;
*Bio::Emboss::Nexus::ajNexusGetTaxa = *Bio::Emboss::ajNexusGetTaxa;
*Bio::Emboss::Nexus::ajNexusGetSequences = *Bio::Emboss::ajNexusGetSequences;
*Bio::Emboss::Nexus::ajNexusTrace = *Bio::Emboss::ajNexusTrace;

*Bio::Emboss::Outfile::ajOutfileClose = *Bio::Emboss::ajOutfileClose;
*Bio::Emboss::Outfile::ajOutfileDel = *Bio::Emboss::ajOutfileDel;
*Bio::Emboss::Outfile::ajOutfileFile = *Bio::Emboss::ajOutfileFile;
*Bio::Emboss::Outfile::ajOutfileFormat = *Bio::Emboss::ajOutfileFormat;
*Bio::Emboss::Outfile::ajOutfileFp = *Bio::Emboss::ajOutfileFp;

*Bio::Emboss::Pdb::ajPdbDel = *Bio::Emboss::ajPdbDel;
*Bio::Emboss::Pdb::ajPdbCopy = *Bio::Emboss::ajPdbCopy;
*Bio::Emboss::Pdb::ajPdbGetEStrideType = *Bio::Emboss::ajPdbGetEStrideType;
*Bio::Emboss::Pdb::ajXyzPdbDel = *Bio::Emboss::ajXyzPdbDel;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexI = *Bio::Emboss::ajXyzPdbAtomIndexI;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexC = *Bio::Emboss::ajXyzPdbAtomIndexC;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexICA = *Bio::Emboss::ajXyzPdbAtomIndexICA;
*Bio::Emboss::Pdb::ajXyzPdbAtomIndexCCA = *Bio::Emboss::ajXyzPdbAtomIndexCCA;
*Bio::Emboss::Pdb::embPdbListHeterogens = *Bio::Emboss::embPdbListHeterogens;
*Bio::Emboss::Pdb::embPdbidToScop = *Bio::Emboss::embPdbidToScop;

*Bio::Emboss::Pdbtosp::ajPdbtospDel = *Bio::Emboss::ajPdbtospDel;
*Bio::Emboss::Pdbtosp::ajPdbtospArrFindPdbid = *Bio::Emboss::ajPdbtospArrFindPdbid;
*Bio::Emboss::Pdbtosp::ajXyzPdbtospDel = *Bio::Emboss::ajXyzPdbtospDel;

*Bio::Emboss::PhyloDist::ajPhyloDistDel = *Bio::Emboss::ajPhyloDistDel;
*Bio::Emboss::PhyloDist::ajPhyloDistTrace = *Bio::Emboss::ajPhyloDistTrace;

*Bio::Emboss::PhyloFreq::ajPhyloFreqDel = *Bio::Emboss::ajPhyloFreqDel;
*Bio::Emboss::PhyloFreq::ajPhyloFreqTrace = *Bio::Emboss::ajPhyloFreqTrace;

*Bio::Emboss::PhyloProp::ajPhyloPropDel = *Bio::Emboss::ajPhyloPropDel;
*Bio::Emboss::PhyloProp::ajPhyloPropGetSize = *Bio::Emboss::ajPhyloPropGetSize;
*Bio::Emboss::PhyloProp::ajPhyloPropTrace = *Bio::Emboss::ajPhyloPropTrace;

*Bio::Emboss::PhyloState::ajPhyloStateDel = *Bio::Emboss::ajPhyloStateDel;
*Bio::Emboss::PhyloState::ajPhyloStateTrace = *Bio::Emboss::ajPhyloStateTrace;

*Bio::Emboss::PhyloTree::ajPhyloTreeDel = *Bio::Emboss::ajPhyloTreeDel;
*Bio::Emboss::PhyloTree::ajPhyloTreeTrace = *Bio::Emboss::ajPhyloTreeTrace;

*Bio::Emboss::Range::ajRangeBegin = *Bio::Emboss::ajRangeBegin;
*Bio::Emboss::Range::ajRangeChange = *Bio::Emboss::ajRangeChange;
*Bio::Emboss::Range::ajRangeCopy = *Bio::Emboss::ajRangeCopy;
*Bio::Emboss::Range::ajRangeDefault = *Bio::Emboss::ajRangeDefault;
*Bio::Emboss::Range::ajRangeDel = *Bio::Emboss::ajRangeDel;
*Bio::Emboss::Range::ajRangeNumber = *Bio::Emboss::ajRangeNumber;
*Bio::Emboss::Range::ajRangeOrdered = *Bio::Emboss::ajRangeOrdered;
*Bio::Emboss::Range::ajRangeOverlaps = *Bio::Emboss::ajRangeOverlaps;
*Bio::Emboss::Range::ajRangeSeqExtract = *Bio::Emboss::ajRangeSeqExtract;
*Bio::Emboss::Range::ajRangeSeqExtractList = *Bio::Emboss::ajRangeSeqExtractList;
*Bio::Emboss::Range::ajRangeSeqMask = *Bio::Emboss::ajRangeSeqMask;
*Bio::Emboss::Range::ajRangeSeqStuff = *Bio::Emboss::ajRangeSeqStuff;
*Bio::Emboss::Range::ajRangeSeqToLower = *Bio::Emboss::ajRangeSeqToLower;
*Bio::Emboss::Range::ajRangeStrExtract = *Bio::Emboss::ajRangeStrExtract;
*Bio::Emboss::Range::ajRangeStrExtractList = *Bio::Emboss::ajRangeStrExtractList;
*Bio::Emboss::Range::ajRangeStrMask = *Bio::Emboss::ajRangeStrMask;
*Bio::Emboss::Range::ajRangeStrStuff = *Bio::Emboss::ajRangeStrStuff;
*Bio::Emboss::Range::ajRangeStrToLower = *Bio::Emboss::ajRangeStrToLower;
*Bio::Emboss::Range::ajRangeText = *Bio::Emboss::ajRangeText;
*Bio::Emboss::Range::ajRangeValues = *Bio::Emboss::ajRangeValues;

*Bio::Emboss::Regexp::ajRegExec = *Bio::Emboss::ajRegExec;
*Bio::Emboss::Regexp::ajRegExecB = *Bio::Emboss::ajRegExecB;
*Bio::Emboss::Regexp::ajRegExecC = *Bio::Emboss::ajRegExecC;
*Bio::Emboss::Regexp::ajRegLenI = *Bio::Emboss::ajRegLenI;
*Bio::Emboss::Regexp::ajRegOffset = *Bio::Emboss::ajRegOffset;
*Bio::Emboss::Regexp::ajRegOffsetI = *Bio::Emboss::ajRegOffsetI;
*Bio::Emboss::Regexp::ajRegPre = *Bio::Emboss::ajRegPre;
*Bio::Emboss::Regexp::ajRegPost = *Bio::Emboss::ajRegPost;
*Bio::Emboss::Regexp::ajRegSubI = *Bio::Emboss::ajRegSubI;
*Bio::Emboss::Regexp::ajRegFree = *Bio::Emboss::ajRegFree;
*Bio::Emboss::Regexp::ajRegTrace = *Bio::Emboss::ajRegTrace;

*Bio::Emboss::Report::ajReportClose = *Bio::Emboss::ajReportClose;
*Bio::Emboss::Report::ajReportDel = *Bio::Emboss::ajReportDel;
*Bio::Emboss::Report::ajReportFileAdd = *Bio::Emboss::ajReportFileAdd;
*Bio::Emboss::Report::ajReportOpen = *Bio::Emboss::ajReportOpen;
*Bio::Emboss::Report::ajReportSeqName = *Bio::Emboss::ajReportSeqName;
*Bio::Emboss::Report::ajReportSetHeader = *Bio::Emboss::ajReportSetHeader;
*Bio::Emboss::Report::ajReportSetHeaderC = *Bio::Emboss::ajReportSetHeaderC;
*Bio::Emboss::Report::ajReportSetSubHeader = *Bio::Emboss::ajReportSetSubHeader;
*Bio::Emboss::Report::ajReportSetSubHeaderC = *Bio::Emboss::ajReportSetSubHeaderC;
*Bio::Emboss::Report::ajReportSetTags = *Bio::Emboss::ajReportSetTags;
*Bio::Emboss::Report::ajReportSetTail = *Bio::Emboss::ajReportSetTail;
*Bio::Emboss::Report::ajReportSetTailC = *Bio::Emboss::ajReportSetTailC;
*Bio::Emboss::Report::ajReportSetSubTail = *Bio::Emboss::ajReportSetSubTail;
*Bio::Emboss::Report::ajReportSetSubTailC = *Bio::Emboss::ajReportSetSubTailC;
*Bio::Emboss::Report::ajReportSetType = *Bio::Emboss::ajReportSetType;
*Bio::Emboss::Report::ajReportValid = *Bio::Emboss::ajReportValid;
*Bio::Emboss::Report::ajReportWrite = *Bio::Emboss::ajReportWrite;
*Bio::Emboss::Report::ajReportWriteHeader = *Bio::Emboss::ajReportWriteHeader;
*Bio::Emboss::Report::ajReportWriteTail = *Bio::Emboss::ajReportWriteTail;

*Bio::Emboss::Residue::ajResidueDel = *Bio::Emboss::ajResidueDel;

*Bio::Emboss::Scop::ajScopDel = *Bio::Emboss::ajScopDel;
*Bio::Emboss::Scop::ajScopCopy = *Bio::Emboss::ajScopCopy;
*Bio::Emboss::Scop::ajScopArrFindScopid = *Bio::Emboss::ajScopArrFindScopid;
*Bio::Emboss::Scop::ajScopArrFindSunid = *Bio::Emboss::ajScopArrFindSunid;
*Bio::Emboss::Scop::ajScopArrFindPdbid = *Bio::Emboss::ajScopArrFindPdbid;
*Bio::Emboss::Scop::ajXyzScopDel = *Bio::Emboss::ajXyzScopDel;
*Bio::Emboss::Scop::ajXyzScopToScophit = *Bio::Emboss::ajXyzScopToScophit;
*Bio::Emboss::Scop::ajXyzScopCopy = *Bio::Emboss::ajXyzScopCopy;
*Bio::Emboss::Scop::embDmxScopToScophit = *Bio::Emboss::embDmxScopToScophit;

*Bio::Emboss::Scopalg::ajDmxScopalgWrite = *Bio::Emboss::ajDmxScopalgWrite;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteClustal = *Bio::Emboss::ajDmxScopalgWriteClustal;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteClustal2 = *Bio::Emboss::ajDmxScopalgWriteClustal2;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteFasta = *Bio::Emboss::ajDmxScopalgWriteFasta;
*Bio::Emboss::Scopalg::ajDmxScopalgDel = *Bio::Emboss::ajDmxScopalgDel;
*Bio::Emboss::Scopalg::ajXyzScopalgWriteClustal = *Bio::Emboss::ajXyzScopalgWriteClustal;
*Bio::Emboss::Scopalg::ajXyzScopalgWriteClustal2 = *Bio::Emboss::ajXyzScopalgWriteClustal2;
*Bio::Emboss::Scopalg::ajXyzScopalgDel = *Bio::Emboss::ajXyzScopalgDel;
*Bio::Emboss::Scopalg::ajXyzScopalgGetseqs = *Bio::Emboss::ajXyzScopalgGetseqs;
*Bio::Emboss::Scopalg::embDmxScopalgToScop = *Bio::Emboss::embDmxScopalgToScop;

*Bio::Emboss::Scopcla::ajXyzScopclaDel = *Bio::Emboss::ajXyzScopclaDel;

*Bio::Emboss::Scopdes::ajXyzScopdesDel = *Bio::Emboss::ajXyzScopdesDel;

*Bio::Emboss::Scophit::ajDmxScophitDel = *Bio::Emboss::ajDmxScophitDel;
*Bio::Emboss::Scophit::ajDmxScophitCheckTarget = *Bio::Emboss::ajDmxScophitCheckTarget;
*Bio::Emboss::Scophit::ajDmxScophitTarget = *Bio::Emboss::ajDmxScophitTarget;
*Bio::Emboss::Scophit::ajDmxScophitTarget2 = *Bio::Emboss::ajDmxScophitTarget2;
*Bio::Emboss::Scophit::ajDmxScophitTargetLowPriority = *Bio::Emboss::ajDmxScophitTargetLowPriority;
*Bio::Emboss::Scophit::ajDmxScophitCopy = *Bio::Emboss::ajDmxScophitCopy;
*Bio::Emboss::Scophit::ajXyzScophitDel = *Bio::Emboss::ajXyzScophitDel;
*Bio::Emboss::Scophit::ajXyzScophitsOverlap = *Bio::Emboss::ajXyzScophitsOverlap;
*Bio::Emboss::Scophit::ajXyzScophitsOverlapAcc = *Bio::Emboss::ajXyzScophitsOverlapAcc;
*Bio::Emboss::Scophit::ajXyzScophitCopy = *Bio::Emboss::ajXyzScophitCopy;
*Bio::Emboss::Scophit::ajXyzScophitCheckTarget = *Bio::Emboss::ajXyzScophitCheckTarget;
*Bio::Emboss::Scophit::ajXyzScophitTarget = *Bio::Emboss::ajXyzScophitTarget;
*Bio::Emboss::Scophit::ajXyzScophitTarget2 = *Bio::Emboss::ajXyzScophitTarget2;
*Bio::Emboss::Scophit::ajXyzScophitTargetLowPriority = *Bio::Emboss::ajXyzScophitTargetLowPriority;
*Bio::Emboss::Scophit::ajXyzScophitMerge = *Bio::Emboss::ajXyzScophitMerge;
*Bio::Emboss::Scophit::embDmxScophitsOverlap = *Bio::Emboss::embDmxScophitsOverlap;
*Bio::Emboss::Scophit::embDmxScophitsOverlapAcc = *Bio::Emboss::embDmxScophitsOverlapAcc;
*Bio::Emboss::Scophit::embDmxScophitMerge = *Bio::Emboss::embDmxScophitMerge;

*Bio::Emboss::Scorealg::ajXyzScorealgDel = *Bio::Emboss::ajXyzScorealgDel;

*Bio::Emboss::Selex::ajSelexDel = *Bio::Emboss::ajSelexDel;

*Bio::Emboss::SelexSQ::ajSelexSQDel = *Bio::Emboss::ajSelexSQDel;

*Bio::Emboss::Selexdata::ajSelexdataDel = *Bio::Emboss::ajSelexdataDel;

*Bio::Emboss::Seq::ajFeattableNewSeq = *Bio::Emboss::ajFeattableNewSeq;
*Bio::Emboss::Seq::ajSeqAssAcc = *Bio::Emboss::ajSeqAssAcc;
*Bio::Emboss::Seq::ajSeqAssAccC = *Bio::Emboss::ajSeqAssAccC;
*Bio::Emboss::Seq::ajSeqAssDesc = *Bio::Emboss::ajSeqAssDesc;
*Bio::Emboss::Seq::ajSeqAssDescC = *Bio::Emboss::ajSeqAssDescC;
*Bio::Emboss::Seq::ajSeqAssEntry = *Bio::Emboss::ajSeqAssEntry;
*Bio::Emboss::Seq::ajSeqAssEntryC = *Bio::Emboss::ajSeqAssEntryC;
*Bio::Emboss::Seq::ajSeqAssFile = *Bio::Emboss::ajSeqAssFile;
*Bio::Emboss::Seq::ajSeqAssFull = *Bio::Emboss::ajSeqAssFull;
*Bio::Emboss::Seq::ajSeqAssFullC = *Bio::Emboss::ajSeqAssFullC;
*Bio::Emboss::Seq::ajSeqAssGi = *Bio::Emboss::ajSeqAssGi;
*Bio::Emboss::Seq::ajSeqAssGiC = *Bio::Emboss::ajSeqAssGiC;
*Bio::Emboss::Seq::ajSeqAssName = *Bio::Emboss::ajSeqAssName;
*Bio::Emboss::Seq::ajSeqAssNameC = *Bio::Emboss::ajSeqAssNameC;
*Bio::Emboss::Seq::ajSeqAssSeq = *Bio::Emboss::ajSeqAssSeq;
*Bio::Emboss::Seq::ajSeqAssSeqC = *Bio::Emboss::ajSeqAssSeqC;
*Bio::Emboss::Seq::ajSeqAssSeqCI = *Bio::Emboss::ajSeqAssSeqCI;
*Bio::Emboss::Seq::ajSeqAssSv = *Bio::Emboss::ajSeqAssSv;
*Bio::Emboss::Seq::ajSeqAssSvC = *Bio::Emboss::ajSeqAssSvC;
*Bio::Emboss::Seq::ajSeqAssUfo = *Bio::Emboss::ajSeqAssUfo;
*Bio::Emboss::Seq::ajSeqAssUfoC = *Bio::Emboss::ajSeqAssUfoC;
*Bio::Emboss::Seq::ajSeqAssUsa = *Bio::Emboss::ajSeqAssUsa;
*Bio::Emboss::Seq::ajSeqAssUsaC = *Bio::Emboss::ajSeqAssUsaC;
*Bio::Emboss::Seq::ajSeqBegin = *Bio::Emboss::ajSeqBegin;
*Bio::Emboss::Seq::ajSeqChar = *Bio::Emboss::ajSeqChar;
*Bio::Emboss::Seq::ajSeqCharCopy = *Bio::Emboss::ajSeqCharCopy;
*Bio::Emboss::Seq::ajSeqCharCopyL = *Bio::Emboss::ajSeqCharCopyL;
*Bio::Emboss::Seq::ajSeqCheckGcg = *Bio::Emboss::ajSeqCheckGcg;
*Bio::Emboss::Seq::ajSeqClear = *Bio::Emboss::ajSeqClear;
*Bio::Emboss::Seq::ajSeqCompOnly = *Bio::Emboss::ajSeqCompOnly;
*Bio::Emboss::Seq::ajSeqGarbageOn = *Bio::Emboss::ajSeqGarbageOn;
*Bio::Emboss::Seq::ajSeqGarbageOff = *Bio::Emboss::ajSeqGarbageOff;
*Bio::Emboss::Seq::ajSeqCopyFeat = *Bio::Emboss::ajSeqCopyFeat;
*Bio::Emboss::Seq::ajSeqDel = *Bio::Emboss::ajSeqDel;
*Bio::Emboss::Seq::ajSeqEnd = *Bio::Emboss::ajSeqEnd;
*Bio::Emboss::Seq::ajSeqFill = *Bio::Emboss::ajSeqFill;
*Bio::Emboss::Seq::ajSeqGapCount = *Bio::Emboss::ajSeqGapCount;
*Bio::Emboss::Seq::ajSeqGapStandard = *Bio::Emboss::ajSeqGapStandard;
*Bio::Emboss::Seq::ajSeqGetAcc = *Bio::Emboss::ajSeqGetAcc;
*Bio::Emboss::Seq::ajSeqGetDesc = *Bio::Emboss::ajSeqGetDesc;
*Bio::Emboss::Seq::ajSeqGetEntry = *Bio::Emboss::ajSeqGetEntry;
*Bio::Emboss::Seq::ajSeqGetFeat = *Bio::Emboss::ajSeqGetFeat;
*Bio::Emboss::Seq::ajSeqGetGi = *Bio::Emboss::ajSeqGetGi;
*Bio::Emboss::Seq::ajSeqGetName = *Bio::Emboss::ajSeqGetName;
*Bio::Emboss::Seq::ajSeqGetRange = *Bio::Emboss::ajSeqGetRange;
*Bio::Emboss::Seq::ajSeqGetReverse = *Bio::Emboss::ajSeqGetReverse;
*Bio::Emboss::Seq::ajSeqGetReversed = *Bio::Emboss::ajSeqGetReversed;
*Bio::Emboss::Seq::ajSeqGetSv = *Bio::Emboss::ajSeqGetSv;
*Bio::Emboss::Seq::ajSeqGetTax = *Bio::Emboss::ajSeqGetTax;
*Bio::Emboss::Seq::ajSeqGetUsa = *Bio::Emboss::ajSeqGetUsa;
*Bio::Emboss::Seq::ajSeqIsNuc = *Bio::Emboss::ajSeqIsNuc;
*Bio::Emboss::Seq::ajSeqIsProt = *Bio::Emboss::ajSeqIsProt;
*Bio::Emboss::Seq::ajSeqLen = *Bio::Emboss::ajSeqLen;
*Bio::Emboss::Seq::ajSeqMakeUsa = *Bio::Emboss::ajSeqMakeUsa;
*Bio::Emboss::Seq::ajSeqMakeUsaS = *Bio::Emboss::ajSeqMakeUsaS;
*Bio::Emboss::Seq::ajSeqMod = *Bio::Emboss::ajSeqMod;
*Bio::Emboss::Seq::ajSeqName = *Bio::Emboss::ajSeqName;
*Bio::Emboss::Seq::ajSeqNewS = *Bio::Emboss::ajSeqNewS;
*Bio::Emboss::Seq::ajSeqNum = *Bio::Emboss::ajSeqNum;
*Bio::Emboss::Seq::ajSeqIsGarbage = *Bio::Emboss::ajSeqIsGarbage;
*Bio::Emboss::Seq::ajSeqIsReversed = *Bio::Emboss::ajSeqIsReversed;
*Bio::Emboss::Seq::ajSeqIsTrimmed = *Bio::Emboss::ajSeqIsTrimmed;
*Bio::Emboss::Seq::ajSeqOffset = *Bio::Emboss::ajSeqOffset;
*Bio::Emboss::Seq::ajSeqOffend = *Bio::Emboss::ajSeqOffend;
*Bio::Emboss::Seq::ajSeqPos = *Bio::Emboss::ajSeqPos;
*Bio::Emboss::Seq::ajSeqPosI = *Bio::Emboss::ajSeqPosI;
*Bio::Emboss::Seq::ajSeqReplace = *Bio::Emboss::ajSeqReplace;
*Bio::Emboss::Seq::ajSeqReplaceC = *Bio::Emboss::ajSeqReplaceC;
*Bio::Emboss::Seq::ajSeqRev = *Bio::Emboss::ajSeqRev;
*Bio::Emboss::Seq::ajSeqReverse = *Bio::Emboss::ajSeqReverse;
*Bio::Emboss::Seq::ajSeqReverseForce = *Bio::Emboss::ajSeqReverseForce;
*Bio::Emboss::Seq::ajSeqRevOnly = *Bio::Emboss::ajSeqRevOnly;
*Bio::Emboss::Seq::ajSeqSetOffsets = *Bio::Emboss::ajSeqSetOffsets;
*Bio::Emboss::Seq::ajSeqSetRange = *Bio::Emboss::ajSeqSetRange;
*Bio::Emboss::Seq::ajSeqSetRangeDir = *Bio::Emboss::ajSeqSetRangeDir;
*Bio::Emboss::Seq::ajSeqStr = *Bio::Emboss::ajSeqStr;
*Bio::Emboss::Seq::ajSeqStrCopy = *Bio::Emboss::ajSeqStrCopy;
*Bio::Emboss::Seq::ajSeqToLower = *Bio::Emboss::ajSeqToLower;
*Bio::Emboss::Seq::ajSeqToUpper = *Bio::Emboss::ajSeqToUpper;
*Bio::Emboss::Seq::ajSeqTrace = *Bio::Emboss::ajSeqTrace;
*Bio::Emboss::Seq::ajSeqTraceT = *Bio::Emboss::ajSeqTraceT;
*Bio::Emboss::Seq::ajSeqTrim = *Bio::Emboss::ajSeqTrim;
*Bio::Emboss::Seq::ajSeqTrueBegin = *Bio::Emboss::ajSeqTrueBegin;
*Bio::Emboss::Seq::ajSeqTrueEnd = *Bio::Emboss::ajSeqTrueEnd;
*Bio::Emboss::Seq::ajSeqTrueLen = *Bio::Emboss::ajSeqTrueLen;
*Bio::Emboss::Seq::ajSeqTruePos = *Bio::Emboss::ajSeqTruePos;
*Bio::Emboss::Seq::ajSeqTruePosI = *Bio::Emboss::ajSeqTruePosI;
*Bio::Emboss::Seq::ajSeqAllRead = *Bio::Emboss::ajSeqAllRead;
*Bio::Emboss::Seq::ajSeqRead = *Bio::Emboss::ajSeqRead;
*Bio::Emboss::Seq::ajSeqGap = *Bio::Emboss::ajSeqGap;
*Bio::Emboss::Seq::ajSeqGapLen = *Bio::Emboss::ajSeqGapLen;
*Bio::Emboss::Seq::ajSeqSetNuc = *Bio::Emboss::ajSeqSetNuc;
*Bio::Emboss::Seq::ajSeqSetProt = *Bio::Emboss::ajSeqSetProt;
*Bio::Emboss::Seq::ajSeqType = *Bio::Emboss::ajSeqType;
*Bio::Emboss::Seq::ajSeqTypeCheckIn = *Bio::Emboss::ajSeqTypeCheckIn;
*Bio::Emboss::Seq::ajTrnNewPep = *Bio::Emboss::ajTrnNewPep;
*Bio::Emboss::Seq::embEstAlignNonRecursive = *Bio::Emboss::embEstAlignNonRecursive;
*Bio::Emboss::Seq::embEstAlignLinearSpace = *Bio::Emboss::embEstAlignLinearSpace;
*Bio::Emboss::Seq::embEstFindSpliceSites = *Bio::Emboss::embEstFindSpliceSites;
*Bio::Emboss::Seq::embEstShuffleSeq = *Bio::Emboss::embEstShuffleSeq;
*Bio::Emboss::Seq::embPropProtGaps = *Bio::Emboss::embPropProtGaps;
*Bio::Emboss::Seq::embPropProt1to3 = *Bio::Emboss::embPropProt1to3;
*Bio::Emboss::Seq::embShowNew = *Bio::Emboss::embShowNew;

*Bio::Emboss::SeqCvt::ajSeqCvtDel = *Bio::Emboss::ajSeqCvtDel;
*Bio::Emboss::SeqCvt::ajSeqCvtK = *Bio::Emboss::ajSeqCvtK;
*Bio::Emboss::SeqCvt::ajSeqCvtKS = *Bio::Emboss::ajSeqCvtKS;
*Bio::Emboss::SeqCvt::ajSeqCvtKSRow = *Bio::Emboss::ajSeqCvtKSRow;
*Bio::Emboss::SeqCvt::ajSeqCvtKSColumn = *Bio::Emboss::ajSeqCvtKSColumn;
*Bio::Emboss::SeqCvt::ajSeqCvtLen = *Bio::Emboss::ajSeqCvtLen;
*Bio::Emboss::SeqCvt::ajSeqCvtTrace = *Bio::Emboss::ajSeqCvtTrace;

*Bio::Emboss::SeqQuery::ajNamDbData = *Bio::Emboss::ajNamDbData;
*Bio::Emboss::SeqQuery::ajNamDbQuery = *Bio::Emboss::ajNamDbQuery;
*Bio::Emboss::SeqQuery::ajSeqQueryClear = *Bio::Emboss::ajSeqQueryClear;
*Bio::Emboss::SeqQuery::ajSeqQueryDel = *Bio::Emboss::ajSeqQueryDel;
*Bio::Emboss::SeqQuery::ajSeqQueryIs = *Bio::Emboss::ajSeqQueryIs;
*Bio::Emboss::SeqQuery::ajSeqQueryStarclear = *Bio::Emboss::ajSeqQueryStarclear;
*Bio::Emboss::SeqQuery::ajSeqQueryTrace = *Bio::Emboss::ajSeqQueryTrace;
*Bio::Emboss::SeqQuery::ajSeqQueryWild = *Bio::Emboss::ajSeqQueryWild;

*Bio::Emboss::Seqall::ajSeqallBegin = *Bio::Emboss::ajSeqallBegin;
*Bio::Emboss::Seqall::ajSeqallDel = *Bio::Emboss::ajSeqallDel;
*Bio::Emboss::Seqall::ajSeqallEnd = *Bio::Emboss::ajSeqallEnd;
*Bio::Emboss::Seqall::ajSeqallGetName = *Bio::Emboss::ajSeqallGetName;
*Bio::Emboss::Seqall::ajSeqallGetNameSeq = *Bio::Emboss::ajSeqallGetNameSeq;
*Bio::Emboss::Seqall::ajSeqallGetRange = *Bio::Emboss::ajSeqallGetRange;
*Bio::Emboss::Seqall::ajSeqallGetUsa = *Bio::Emboss::ajSeqallGetUsa;
*Bio::Emboss::Seqall::ajSeqallLen = *Bio::Emboss::ajSeqallLen;
*Bio::Emboss::Seqall::ajSeqallClear = *Bio::Emboss::ajSeqallClear;
*Bio::Emboss::Seqall::ajSeqallNext = *Bio::Emboss::ajSeqallNext;
*Bio::Emboss::Seqall::ajSeqallReverse = *Bio::Emboss::ajSeqallReverse;
*Bio::Emboss::Seqall::ajSeqallSetRange = *Bio::Emboss::ajSeqallSetRange;
*Bio::Emboss::Seqall::ajSeqallToLower = *Bio::Emboss::ajSeqallToLower;
*Bio::Emboss::Seqall::ajSeqallToUpper = *Bio::Emboss::ajSeqallToUpper;

*Bio::Emboss::Seqin::ajSeqinTrace = *Bio::Emboss::ajSeqinTrace;
*Bio::Emboss::Seqin::ajSeqAccessAsis = *Bio::Emboss::ajSeqAccessAsis;
*Bio::Emboss::Seqin::ajSeqAccessFile = *Bio::Emboss::ajSeqAccessFile;
*Bio::Emboss::Seqin::ajSeqAccessOffset = *Bio::Emboss::ajSeqAccessOffset;
*Bio::Emboss::Seqin::ajSeqinClear = *Bio::Emboss::ajSeqinClear;
*Bio::Emboss::Seqin::ajSeqinClearPos = *Bio::Emboss::ajSeqinClearPos;
*Bio::Emboss::Seqin::ajSeqinDel = *Bio::Emboss::ajSeqinDel;
*Bio::Emboss::Seqin::ajSeqinSetNuc = *Bio::Emboss::ajSeqinSetNuc;
*Bio::Emboss::Seqin::ajSeqinSetProt = *Bio::Emboss::ajSeqinSetProt;
*Bio::Emboss::Seqin::ajSeqinSetRange = *Bio::Emboss::ajSeqinSetRange;
*Bio::Emboss::Seqin::ajSeqinUsa = *Bio::Emboss::ajSeqinUsa;

*Bio::Emboss::Seqout::ajSeqAllWrite = *Bio::Emboss::ajSeqAllWrite;
*Bio::Emboss::Seqout::ajSeqFileNewOut = *Bio::Emboss::ajSeqFileNewOut;
*Bio::Emboss::Seqout::ajSeqoutCheckGcg = *Bio::Emboss::ajSeqoutCheckGcg;
*Bio::Emboss::Seqout::ajSeqoutClear = *Bio::Emboss::ajSeqoutClear;
*Bio::Emboss::Seqout::ajSeqoutDel = *Bio::Emboss::ajSeqoutDel;
*Bio::Emboss::Seqout::ajSeqoutOpen = *Bio::Emboss::ajSeqoutOpen;
*Bio::Emboss::Seqout::ajSeqOutSetFormat = *Bio::Emboss::ajSeqOutSetFormat;
*Bio::Emboss::Seqout::ajSeqOutSetFormatC = *Bio::Emboss::ajSeqOutSetFormatC;
*Bio::Emboss::Seqout::ajSeqoutTrace = *Bio::Emboss::ajSeqoutTrace;
*Bio::Emboss::Seqout::ajSeqoutUsa = *Bio::Emboss::ajSeqoutUsa;
*Bio::Emboss::Seqout::ajSeqsetWrite = *Bio::Emboss::ajSeqsetWrite;
*Bio::Emboss::Seqout::ajSeqWrite = *Bio::Emboss::ajSeqWrite;
*Bio::Emboss::Seqout::ajSeqWriteClose = *Bio::Emboss::ajSeqWriteClose;

*Bio::Emboss::Seqset::ajAlignConsStats = *Bio::Emboss::ajAlignConsStats;
*Bio::Emboss::Seqset::ajSeqsetBegin = *Bio::Emboss::ajSeqsetBegin;
*Bio::Emboss::Seqset::ajSeqsetDel = *Bio::Emboss::ajSeqsetDel;
*Bio::Emboss::Seqset::ajSeqsetEnd = *Bio::Emboss::ajSeqsetEnd;
*Bio::Emboss::Seqset::ajSeqsetFill = *Bio::Emboss::ajSeqsetFill;
*Bio::Emboss::Seqset::ajSeqsetGetFormat = *Bio::Emboss::ajSeqsetGetFormat;
*Bio::Emboss::Seqset::ajSeqsetGetName = *Bio::Emboss::ajSeqsetGetName;
*Bio::Emboss::Seqset::ajSeqsetGetRange = *Bio::Emboss::ajSeqsetGetRange;
*Bio::Emboss::Seqset::ajSeqsetGetSeq = *Bio::Emboss::ajSeqsetGetSeq;
*Bio::Emboss::Seqset::ajSeqsetGetUsa = *Bio::Emboss::ajSeqsetGetUsa;
*Bio::Emboss::Seqset::ajSeqsetIsDna = *Bio::Emboss::ajSeqsetIsDna;
*Bio::Emboss::Seqset::ajSeqsetIsNuc = *Bio::Emboss::ajSeqsetIsNuc;
*Bio::Emboss::Seqset::ajSeqsetIsProt = *Bio::Emboss::ajSeqsetIsProt;
*Bio::Emboss::Seqset::ajSeqsetIsRna = *Bio::Emboss::ajSeqsetIsRna;
*Bio::Emboss::Seqset::ajSeqsetLen = *Bio::Emboss::ajSeqsetLen;
*Bio::Emboss::Seqset::ajSeqsetName = *Bio::Emboss::ajSeqsetName;
*Bio::Emboss::Seqset::ajSeqsetAcc = *Bio::Emboss::ajSeqsetAcc;
*Bio::Emboss::Seqset::ajSeqsetReverse = *Bio::Emboss::ajSeqsetReverse;
*Bio::Emboss::Seqset::ajSeqsetSeq = *Bio::Emboss::ajSeqsetSeq;
*Bio::Emboss::Seqset::ajSeqsetSetRange = *Bio::Emboss::ajSeqsetSetRange;
*Bio::Emboss::Seqset::ajSeqsetSize = *Bio::Emboss::ajSeqsetSize;
*Bio::Emboss::Seqset::ajSeqsetToLower = *Bio::Emboss::ajSeqsetToLower;
*Bio::Emboss::Seqset::ajSeqsetTotweight = *Bio::Emboss::ajSeqsetTotweight;
*Bio::Emboss::Seqset::ajSeqsetToUpper = *Bio::Emboss::ajSeqsetToUpper;
*Bio::Emboss::Seqset::ajSeqsetTrim = *Bio::Emboss::ajSeqsetTrim;
*Bio::Emboss::Seqset::ajSeqsetWeight = *Bio::Emboss::ajSeqsetWeight;
*Bio::Emboss::Seqset::ajSeqsetApp = *Bio::Emboss::ajSeqsetApp;
*Bio::Emboss::Seqset::ajSeqsetFromList = *Bio::Emboss::ajSeqsetFromList;
*Bio::Emboss::Seqset::ajSeqsetFromPair = *Bio::Emboss::ajSeqsetFromPair;
*Bio::Emboss::Seqset::ajSeqsetRead = *Bio::Emboss::ajSeqsetRead;
*Bio::Emboss::Seqset::ajSeqsetSetNuc = *Bio::Emboss::ajSeqsetSetNuc;
*Bio::Emboss::Seqset::ajSeqsetSetProt = *Bio::Emboss::ajSeqsetSetProt;
*Bio::Emboss::Seqset::embConsCalc = *Bio::Emboss::embConsCalc;

*Bio::Emboss::Sigdat::ajXyzSigdatDel = *Bio::Emboss::ajXyzSigdatDel;

*Bio::Emboss::Signature::ajXyzSignatureDel = *Bio::Emboss::ajXyzSignatureDel;
*Bio::Emboss::Signature::ajXyzSignatureCompile = *Bio::Emboss::ajXyzSignatureCompile;
*Bio::Emboss::Signature::ajXyzSignatureAlignSeq = *Bio::Emboss::ajXyzSignatureAlignSeq;
*Bio::Emboss::Signature::ajXyzSignatureAlignSeqall = *Bio::Emboss::ajXyzSignatureAlignSeqall;

*Bio::Emboss::Sigpos::ajXyzSigposDel = *Bio::Emboss::ajXyzSigposDel;

*Bio::Emboss::Stockholm::ajStockholmDel = *Bio::Emboss::ajStockholmDel;

*Bio::Emboss::Stockholmdata::ajStockholmdataDel = *Bio::Emboss::ajStockholmdataDel;

*Bio::Emboss::Str::ajAcdProgramS = *Bio::Emboss::ajAcdProgramS;
*Bio::Emboss::Str::ajAlignFindFormat = *Bio::Emboss::ajAlignFindFormat;
*Bio::Emboss::Str::ajAlignFormatDefault = *Bio::Emboss::ajAlignFormatDefault;
*Bio::Emboss::Str::ajCodBacktranslate = *Bio::Emboss::ajCodBacktranslate;
*Bio::Emboss::Str::ajCodIndex = *Bio::Emboss::ajCodIndex;
*Bio::Emboss::Str::ajCodOutFormat = *Bio::Emboss::ajCodOutFormat;
*Bio::Emboss::Str::ajFeatLocToSeq = *Bio::Emboss::ajFeatLocToSeq;
*Bio::Emboss::Str::ajFeatOutFormatDefault = *Bio::Emboss::ajFeatOutFormatDefault;
*Bio::Emboss::Str::ajFeattableNew = *Bio::Emboss::ajFeattableNew;
*Bio::Emboss::Str::ajFeattableNewDna = *Bio::Emboss::ajFeattableNewDna;
*Bio::Emboss::Str::ajFeattableNewProt = *Bio::Emboss::ajFeattableNewProt;
*Bio::Emboss::Str::ajFeattabInNewSS = *Bio::Emboss::ajFeattabInNewSS;
*Bio::Emboss::Str::ajFeattabInNewSSF = *Bio::Emboss::ajFeattabInNewSSF;
*Bio::Emboss::Str::ajFeattabOutNewSSF = *Bio::Emboss::ajFeattabOutNewSSF;
*Bio::Emboss::Str::ajDirNew = *Bio::Emboss::ajDirNew;
*Bio::Emboss::Str::ajDirNewS = *Bio::Emboss::ajDirNewS;
*Bio::Emboss::Str::ajDirNewSS = *Bio::Emboss::ajDirNewSS;
*Bio::Emboss::Str::ajDiroutNew = *Bio::Emboss::ajDiroutNew;
*Bio::Emboss::Str::ajDiroutNewS = *Bio::Emboss::ajDiroutNewS;
*Bio::Emboss::Str::ajDiroutNewSS = *Bio::Emboss::ajDiroutNewSS;
*Bio::Emboss::Str::ajFileBuffNewDC = *Bio::Emboss::ajFileBuffNewDC;
*Bio::Emboss::Str::ajFileBuffNewDF = *Bio::Emboss::ajFileBuffNewDF;
*Bio::Emboss::Str::ajFileBuffNewDW = *Bio::Emboss::ajFileBuffNewDW;
*Bio::Emboss::Str::ajFileBuffNewDWE = *Bio::Emboss::ajFileBuffNewDWE;
*Bio::Emboss::Str::ajFileBuffNewIn = *Bio::Emboss::ajFileBuffNewIn;
*Bio::Emboss::Str::ajFileBuffNewS = *Bio::Emboss::ajFileBuffNewS;
*Bio::Emboss::Str::ajFileDataDirNew = *Bio::Emboss::ajFileDataDirNew;
*Bio::Emboss::Str::ajFileDataNew = *Bio::Emboss::ajFileDataNew;
*Bio::Emboss::Str::ajFileDataNewWrite = *Bio::Emboss::ajFileDataNewWrite;
*Bio::Emboss::Str::ajFileDir = *Bio::Emboss::ajFileDir;
*Bio::Emboss::Str::ajFileDirFix = *Bio::Emboss::ajFileDirFix;
*Bio::Emboss::Str::ajFileDirUp = *Bio::Emboss::ajFileDirUp;
*Bio::Emboss::Str::ajFileDirPath = *Bio::Emboss::ajFileDirPath;
*Bio::Emboss::Str::ajFileDirTrim = *Bio::Emboss::ajFileDirTrim;
*Bio::Emboss::Str::ajFileExtnTrim = *Bio::Emboss::ajFileExtnTrim;
*Bio::Emboss::Str::ajFileDirExtnTrim = *Bio::Emboss::ajFileDirExtnTrim;
*Bio::Emboss::Str::ajFileFileList = *Bio::Emboss::ajFileFileList;
*Bio::Emboss::Str::ajFileGetwd = *Bio::Emboss::ajFileGetwd;
*Bio::Emboss::Str::ajFileHasDir = *Bio::Emboss::ajFileHasDir;
*Bio::Emboss::Str::ajFileLength = *Bio::Emboss::ajFileLength;
*Bio::Emboss::Str::ajFileNameDir = *Bio::Emboss::ajFileNameDir;
*Bio::Emboss::Str::ajFileNameDirSet = *Bio::Emboss::ajFileNameDirSet;
*Bio::Emboss::Str::ajFileNameDirSetC = *Bio::Emboss::ajFileNameDirSetC;
*Bio::Emboss::Str::ajFileNameExt = *Bio::Emboss::ajFileNameExt;
*Bio::Emboss::Str::ajFileNameExtC = *Bio::Emboss::ajFileNameExtC;
*Bio::Emboss::Str::ajFileNameShorten = *Bio::Emboss::ajFileNameShorten;
*Bio::Emboss::Str::ajFileNameTrim = *Bio::Emboss::ajFileNameTrim;
*Bio::Emboss::Str::ajFileNewApp = *Bio::Emboss::ajFileNewApp;
*Bio::Emboss::Str::ajFileNewDC = *Bio::Emboss::ajFileNewDC;
*Bio::Emboss::Str::ajFileNewDF = *Bio::Emboss::ajFileNewDF;
*Bio::Emboss::Str::ajFileNewDW = *Bio::Emboss::ajFileNewDW;
*Bio::Emboss::Str::ajFileNewDWE = *Bio::Emboss::ajFileNewDWE;
*Bio::Emboss::Str::ajFileNewIn = *Bio::Emboss::ajFileNewIn;
*Bio::Emboss::Str::ajFileNewInPipe = *Bio::Emboss::ajFileNewInPipe;
*Bio::Emboss::Str::ajFileNewOut = *Bio::Emboss::ajFileNewOut;
*Bio::Emboss::Str::ajFileNewOutD = *Bio::Emboss::ajFileNewOutD;
*Bio::Emboss::Str::ajFileScan = *Bio::Emboss::ajFileScan;
*Bio::Emboss::Str::ajFileSetDir = *Bio::Emboss::ajFileSetDir;
*Bio::Emboss::Str::ajFileStat = *Bio::Emboss::ajFileStat;
*Bio::Emboss::Str::ajFileTestSkip = *Bio::Emboss::ajFileTestSkip;
*Bio::Emboss::Str::ajOutfileNew = *Bio::Emboss::ajOutfileNew;
*Bio::Emboss::Str::ajGraphCheckColour = *Bio::Emboss::ajGraphCheckColour;
*Bio::Emboss::Str::ajNamDatabase = *Bio::Emboss::ajNamDatabase;
*Bio::Emboss::Str::ajNamDbDetails = *Bio::Emboss::ajNamDbDetails;
*Bio::Emboss::Str::ajNamDbGetDbalias = *Bio::Emboss::ajNamDbGetDbalias;
*Bio::Emboss::Str::ajNamDbGetUrl = *Bio::Emboss::ajNamDbGetUrl;
*Bio::Emboss::Str::ajNamDbTest = *Bio::Emboss::ajNamDbTest;
*Bio::Emboss::Str::ajNamGetenv = *Bio::Emboss::ajNamGetenv;
*Bio::Emboss::Str::ajNamGetValue = *Bio::Emboss::ajNamGetValue;
*Bio::Emboss::Str::ajNamIsDbname = *Bio::Emboss::ajNamIsDbname;
*Bio::Emboss::Str::ajNamResolve = *Bio::Emboss::ajNamResolve;
*Bio::Emboss::Str::ajNamRoot = *Bio::Emboss::ajNamRoot;
*Bio::Emboss::Str::ajNamRootBase = *Bio::Emboss::ajNamRootBase;
*Bio::Emboss::Str::ajNamRootInstall = *Bio::Emboss::ajNamRootInstall;
*Bio::Emboss::Str::ajNamRootPack = *Bio::Emboss::ajNamRootPack;
*Bio::Emboss::Str::ajNamRootVersion = *Bio::Emboss::ajNamRootVersion;
*Bio::Emboss::Str::ajNamRsAttrValue = *Bio::Emboss::ajNamRsAttrValue;
*Bio::Emboss::Str::ajNamRsListValue = *Bio::Emboss::ajNamRsListValue;
*Bio::Emboss::Str::ajPhyloDistRead = *Bio::Emboss::ajPhyloDistRead;
*Bio::Emboss::Str::ajPhyloFreqRead = *Bio::Emboss::ajPhyloFreqRead;
*Bio::Emboss::Str::ajPhyloPropRead = *Bio::Emboss::ajPhyloPropRead;
*Bio::Emboss::Str::ajPhyloStateRead = *Bio::Emboss::ajPhyloStateRead;
*Bio::Emboss::Str::ajPhyloTreeRead = *Bio::Emboss::ajPhyloTreeRead;
*Bio::Emboss::Str::ajRangeFile = *Bio::Emboss::ajRangeFile;
*Bio::Emboss::Str::ajRangeGet = *Bio::Emboss::ajRangeGet;
*Bio::Emboss::Str::ajRegComp = *Bio::Emboss::ajRegComp;
*Bio::Emboss::Str::ajRegCompCase = *Bio::Emboss::ajRegCompCase;
*Bio::Emboss::Str::ajReportFindFormat = *Bio::Emboss::ajReportFindFormat;
*Bio::Emboss::Str::ajReportFormatDefault = *Bio::Emboss::ajReportFormatDefault;
*Bio::Emboss::Str::ajIsAccession = *Bio::Emboss::ajIsAccession;
*Bio::Emboss::Str::ajIsSeqversion = *Bio::Emboss::ajIsSeqversion;
*Bio::Emboss::Str::ajSeqCompOnlyStr = *Bio::Emboss::ajSeqCompOnlyStr;
*Bio::Emboss::Str::ajSeqCount = *Bio::Emboss::ajSeqCount;
*Bio::Emboss::Str::ajSeqCrc = *Bio::Emboss::ajSeqCrc;
*Bio::Emboss::Str::ajSeqGapCountS = *Bio::Emboss::ajSeqGapCountS;
*Bio::Emboss::Str::ajSeqGapStandardS = *Bio::Emboss::ajSeqGapStandardS;
*Bio::Emboss::Str::ajSeqMW = *Bio::Emboss::ajSeqMW;
*Bio::Emboss::Str::ajSeqNewRange = *Bio::Emboss::ajSeqNewRange;
*Bio::Emboss::Str::ajSeqNewStr = *Bio::Emboss::ajSeqNewStr;
*Bio::Emboss::Str::ajSeqNumS = *Bio::Emboss::ajSeqNumS;
*Bio::Emboss::Str::ajSeqReverseStr = *Bio::Emboss::ajSeqReverseStr;
*Bio::Emboss::Str::ajSeqFindOutFormat = *Bio::Emboss::ajSeqFindOutFormat;
*Bio::Emboss::Str::ajSeqMethod = *Bio::Emboss::ajSeqMethod;
*Bio::Emboss::Str::ajSeqMethodTest = *Bio::Emboss::ajSeqMethodTest;
*Bio::Emboss::Str::ajSeqallFile = *Bio::Emboss::ajSeqallFile;
*Bio::Emboss::Str::ajSeqGetFromUsa = *Bio::Emboss::ajSeqGetFromUsa;
*Bio::Emboss::Str::ajSeqFormatTest = *Bio::Emboss::ajSeqFormatTest;
*Bio::Emboss::Str::ajSeqParseFasta = *Bio::Emboss::ajSeqParseFasta;
*Bio::Emboss::Str::ajSeqParseNcbi = *Bio::Emboss::ajSeqParseNcbi;
*Bio::Emboss::Str::ajSeqsetGetFromUsa = *Bio::Emboss::ajSeqsetGetFromUsa;
*Bio::Emboss::Str::ajSeqGapS = *Bio::Emboss::ajSeqGapS;
*Bio::Emboss::Str::ajSeqTypeAnyprotS = *Bio::Emboss::ajSeqTypeAnyprotS;
*Bio::Emboss::Str::ajSeqTypeDnaS = *Bio::Emboss::ajSeqTypeDnaS;
*Bio::Emboss::Str::ajSeqTypeGapanyS = *Bio::Emboss::ajSeqTypeGapanyS;
*Bio::Emboss::Str::ajSeqTypeGapdnaS = *Bio::Emboss::ajSeqTypeGapdnaS;
*Bio::Emboss::Str::ajSeqTypeGapnucS = *Bio::Emboss::ajSeqTypeGapnucS;
*Bio::Emboss::Str::ajSeqTypeGaprnaS = *Bio::Emboss::ajSeqTypeGaprnaS;
*Bio::Emboss::Str::ajSeqTypeNucS = *Bio::Emboss::ajSeqTypeNucS;
*Bio::Emboss::Str::ajSeqTypeProtS = *Bio::Emboss::ajSeqTypeProtS;
*Bio::Emboss::Str::ajSeqTypeRnaS = *Bio::Emboss::ajSeqTypeRnaS;
*Bio::Emboss::Str::ajSeqTypeIsAny = *Bio::Emboss::ajSeqTypeIsAny;
*Bio::Emboss::Str::ajSeqTypeIsNuc = *Bio::Emboss::ajSeqTypeIsNuc;
*Bio::Emboss::Str::ajSeqTypeIsProt = *Bio::Emboss::ajSeqTypeIsProt;
*Bio::Emboss::Str::ajSeqTypeCheckS = *Bio::Emboss::ajSeqTypeCheckS;
*Bio::Emboss::Str::ajSeqOutFormatDefault = *Bio::Emboss::ajSeqOutFormatDefault;
*Bio::Emboss::Str::ajSeqOutFormatSingle = *Bio::Emboss::ajSeqOutFormatSingle;
*Bio::Emboss::Str::ajCharNew = *Bio::Emboss::ajCharNew;
*Bio::Emboss::Str::ajStrApp = *Bio::Emboss::ajStrApp;
*Bio::Emboss::Str::ajStrAppC = *Bio::Emboss::ajStrAppC;
*Bio::Emboss::Str::ajStrAppCI = *Bio::Emboss::ajStrAppCI;
*Bio::Emboss::Str::ajStrAppK = *Bio::Emboss::ajStrAppK;
*Bio::Emboss::Str::ajStrAppKI = *Bio::Emboss::ajStrAppKI;
*Bio::Emboss::Str::ajStrAppSub = *Bio::Emboss::ajStrAppSub;
*Bio::Emboss::Str::ajStrArrayDel = *Bio::Emboss::ajStrArrayDel;
*Bio::Emboss::Str::ajStrAss = *Bio::Emboss::ajStrAss;
*Bio::Emboss::Str::ajStrAssC = *Bio::Emboss::ajStrAssC;
*Bio::Emboss::Str::ajStrAssCI = *Bio::Emboss::ajStrAssCI;
*Bio::Emboss::Str::ajStrAssCL = *Bio::Emboss::ajStrAssCL;
*Bio::Emboss::Str::ajStrAssI = *Bio::Emboss::ajStrAssI;
*Bio::Emboss::Str::ajStrAssK = *Bio::Emboss::ajStrAssK;
*Bio::Emboss::Str::ajStrAssL = *Bio::Emboss::ajStrAssL;
*Bio::Emboss::Str::ajStrAssS = *Bio::Emboss::ajStrAssS;
*Bio::Emboss::Str::ajStrAssSub = *Bio::Emboss::ajStrAssSub;
*Bio::Emboss::Str::ajStrAssSubC = *Bio::Emboss::ajStrAssSubC;
*Bio::Emboss::Str::ajStrBlock = *Bio::Emboss::ajStrBlock;
*Bio::Emboss::Str::ajStrChar = *Bio::Emboss::ajStrChar;
*Bio::Emboss::Str::ajStrCheck = *Bio::Emboss::ajStrCheck;
*Bio::Emboss::Str::ajStrChomp = *Bio::Emboss::ajStrChomp;
*Bio::Emboss::Str::ajStrChompC = *Bio::Emboss::ajStrChompC;
*Bio::Emboss::Str::ajStrChompEnd = *Bio::Emboss::ajStrChompEnd;
*Bio::Emboss::Str::ajStrChop = *Bio::Emboss::ajStrChop;
*Bio::Emboss::Str::ajStrClean = *Bio::Emboss::ajStrClean;
*Bio::Emboss::Str::ajStrCleanWhite = *Bio::Emboss::ajStrCleanWhite;
*Bio::Emboss::Str::ajStrClear = *Bio::Emboss::ajStrClear;
*Bio::Emboss::Str::ajStrCmpC = *Bio::Emboss::ajStrCmpC;
*Bio::Emboss::Str::ajStrCmpCase = *Bio::Emboss::ajStrCmpCase;
*Bio::Emboss::Str::ajStrCmpO = *Bio::Emboss::ajStrCmpO;
*Bio::Emboss::Str::ajStrCmpWild = *Bio::Emboss::ajStrCmpWild;
*Bio::Emboss::Str::ajStrCmpWildC = *Bio::Emboss::ajStrCmpWildC;
*Bio::Emboss::Str::ajStrConvert = *Bio::Emboss::ajStrConvert;
*Bio::Emboss::Str::ajStrConvertCC = *Bio::Emboss::ajStrConvertCC;
*Bio::Emboss::Str::ajStrCopy = *Bio::Emboss::ajStrCopy;
*Bio::Emboss::Str::ajStrCopyC = *Bio::Emboss::ajStrCopyC;
*Bio::Emboss::Str::ajStrCountC = *Bio::Emboss::ajStrCountC;
*Bio::Emboss::Str::ajStrCountK = *Bio::Emboss::ajStrCountK;
*Bio::Emboss::Str::ajStrCut = *Bio::Emboss::ajStrCut;
*Bio::Emboss::Str::ajStrDegap = *Bio::Emboss::ajStrDegap;
*Bio::Emboss::Str::ajStrDel = *Bio::Emboss::ajStrDel;
*Bio::Emboss::Str::ajStrDelim = *Bio::Emboss::ajStrDelim;
*Bio::Emboss::Str::ajStrDelReuse = *Bio::Emboss::ajStrDelReuse;
*Bio::Emboss::Str::ajStrDup = *Bio::Emboss::ajStrDup;
*Bio::Emboss::Str::ajStrFind = *Bio::Emboss::ajStrFind;
*Bio::Emboss::Str::ajStrFindAny = *Bio::Emboss::ajStrFindAny;
*Bio::Emboss::Str::ajStrFindAnyC = *Bio::Emboss::ajStrFindAnyC;
*Bio::Emboss::Str::ajStrFindC = *Bio::Emboss::ajStrFindC;
*Bio::Emboss::Str::ajStrFindCase = *Bio::Emboss::ajStrFindCase;
*Bio::Emboss::Str::ajStrFindCaseC = *Bio::Emboss::ajStrFindCaseC;
*Bio::Emboss::Str::ajStrFindK = *Bio::Emboss::ajStrFindK;
*Bio::Emboss::Str::ajStrFill = *Bio::Emboss::ajStrFill;
*Bio::Emboss::Str::ajStrFix = *Bio::Emboss::ajStrFix;
*Bio::Emboss::Str::ajStrFixI = *Bio::Emboss::ajStrFixI;
*Bio::Emboss::Str::ajStrFixTestI = *Bio::Emboss::ajStrFixTestI;
*Bio::Emboss::Str::ajStrFromBool = *Bio::Emboss::ajStrFromBool;
*Bio::Emboss::Str::ajStrFromDouble = *Bio::Emboss::ajStrFromDouble;
*Bio::Emboss::Str::ajStrFromDoubleE = *Bio::Emboss::ajStrFromDoubleE;
*Bio::Emboss::Str::ajStrFromFloat = *Bio::Emboss::ajStrFromFloat;
*Bio::Emboss::Str::ajStrFromInt = *Bio::Emboss::ajStrFromInt;
*Bio::Emboss::Str::ajStrFromLong = *Bio::Emboss::ajStrFromLong;
*Bio::Emboss::Str::ajStrInsert = *Bio::Emboss::ajStrInsert;
*Bio::Emboss::Str::ajStrInsertC = *Bio::Emboss::ajStrInsertC;
*Bio::Emboss::Str::ajStrInsertK = *Bio::Emboss::ajStrInsertK;
*Bio::Emboss::Str::ajStrIsAlnum = *Bio::Emboss::ajStrIsAlnum;
*Bio::Emboss::Str::ajStrIsAlpha = *Bio::Emboss::ajStrIsAlpha;
*Bio::Emboss::Str::ajStrIsBool = *Bio::Emboss::ajStrIsBool;
*Bio::Emboss::Str::ajStrIsDouble = *Bio::Emboss::ajStrIsDouble;
*Bio::Emboss::Str::ajStrIsFloat = *Bio::Emboss::ajStrIsFloat;
*Bio::Emboss::Str::ajStrIsHex = *Bio::Emboss::ajStrIsHex;
*Bio::Emboss::Str::ajStrIsInt = *Bio::Emboss::ajStrIsInt;
*Bio::Emboss::Str::ajStrIsLong = *Bio::Emboss::ajStrIsLong;
*Bio::Emboss::Str::ajStrIsLower = *Bio::Emboss::ajStrIsLower;
*Bio::Emboss::Str::ajStrIsNum = *Bio::Emboss::ajStrIsNum;
*Bio::Emboss::Str::ajStrIsSpace = *Bio::Emboss::ajStrIsSpace;
*Bio::Emboss::Str::ajStrIsUpper = *Bio::Emboss::ajStrIsUpper;
*Bio::Emboss::Str::ajStrIsWild = *Bio::Emboss::ajStrIsWild;
*Bio::Emboss::Str::ajStrIsWhite = *Bio::Emboss::ajStrIsWhite;
*Bio::Emboss::Str::ajStrIsWord = *Bio::Emboss::ajStrIsWord;
*Bio::Emboss::Str::ajStrIter = *Bio::Emboss::ajStrIter;
*Bio::Emboss::Str::ajStrIterBack = *Bio::Emboss::ajStrIterBack;
*Bio::Emboss::Str::ajStrJoin = *Bio::Emboss::ajStrJoin;
*Bio::Emboss::Str::ajStrJoinC = *Bio::Emboss::ajStrJoinC;
*Bio::Emboss::Str::ajStrKeepAlphaC = *Bio::Emboss::ajStrKeepAlphaC;
*Bio::Emboss::Str::ajStrKeepC = *Bio::Emboss::ajStrKeepC;
*Bio::Emboss::Str::ajStrLen = *Bio::Emboss::ajStrLen;
*Bio::Emboss::Str::ajStrListToArray = *Bio::Emboss::ajStrListToArray;
*Bio::Emboss::Str::ajStrMask = *Bio::Emboss::ajStrMask;
*Bio::Emboss::Str::ajStrMatch = *Bio::Emboss::ajStrMatch;
*Bio::Emboss::Str::ajStrMatchC = *Bio::Emboss::ajStrMatchC;
*Bio::Emboss::Str::ajStrMatchCase = *Bio::Emboss::ajStrMatchCase;
*Bio::Emboss::Str::ajStrMatchCaseC = *Bio::Emboss::ajStrMatchCaseC;
*Bio::Emboss::Str::ajStrMatchWild = *Bio::Emboss::ajStrMatchWild;
*Bio::Emboss::Str::ajStrMatchWildC = *Bio::Emboss::ajStrMatchWildC;
*Bio::Emboss::Str::ajStrMatchWord = *Bio::Emboss::ajStrMatchWord;
*Bio::Emboss::Str::ajStrMatchWordC = *Bio::Emboss::ajStrMatchWordC;
*Bio::Emboss::Str::ajStrMod = *Bio::Emboss::ajStrMod;
*Bio::Emboss::Str::ajStrModL = *Bio::Emboss::ajStrModL;
*Bio::Emboss::Str::ajStrModMinL = *Bio::Emboss::ajStrModMinL;
*Bio::Emboss::Str::ajStrNCmpC = *Bio::Emboss::ajStrNCmpC;
*Bio::Emboss::Str::ajStrNCmpO = *Bio::Emboss::ajStrNCmpO;
*Bio::Emboss::Str::ajStrNewS = *Bio::Emboss::ajStrNewS;
*Bio::Emboss::Str::ajStrParentheses = *Bio::Emboss::ajStrParentheses;
*Bio::Emboss::Str::ajStrPos = *Bio::Emboss::ajStrPos;
*Bio::Emboss::Str::ajStrPosI = *Bio::Emboss::ajStrPosI;
*Bio::Emboss::Str::ajStrPrefix = *Bio::Emboss::ajStrPrefix;
*Bio::Emboss::Str::ajStrPrefixC = *Bio::Emboss::ajStrPrefixC;
*Bio::Emboss::Str::ajStrPrefixCase = *Bio::Emboss::ajStrPrefixCase;
*Bio::Emboss::Str::ajStrPrefixCaseC = *Bio::Emboss::ajStrPrefixCaseC;
*Bio::Emboss::Str::ajStrQuote = *Bio::Emboss::ajStrQuote;
*Bio::Emboss::Str::ajStrQuoteStrip = *Bio::Emboss::ajStrQuoteStrip;
*Bio::Emboss::Str::ajStrQuoteStripAll = *Bio::Emboss::ajStrQuoteStripAll;
*Bio::Emboss::Str::ajStrRandom = *Bio::Emboss::ajStrRandom;
*Bio::Emboss::Str::ajStrReplace = *Bio::Emboss::ajStrReplace;
*Bio::Emboss::Str::ajStrReplaceC = *Bio::Emboss::ajStrReplaceC;
*Bio::Emboss::Str::ajStrReplaceK = *Bio::Emboss::ajStrReplaceK;
*Bio::Emboss::Str::ajStrReplaceS = *Bio::Emboss::ajStrReplaceS;
*Bio::Emboss::Str::ajStrRef = *Bio::Emboss::ajStrRef;
*Bio::Emboss::Str::ajStrRemoveCharsC = *Bio::Emboss::ajStrRemoveCharsC;
*Bio::Emboss::Str::ajStrRemoveHtml = *Bio::Emboss::ajStrRemoveHtml;
*Bio::Emboss::Str::ajStrRemoveNewline = *Bio::Emboss::ajStrRemoveNewline;
*Bio::Emboss::Str::ajStrRev = *Bio::Emboss::ajStrRev;
*Bio::Emboss::Str::ajStrRFindC = *Bio::Emboss::ajStrRFindC;
*Bio::Emboss::Str::ajStrRoom = *Bio::Emboss::ajStrRoom;
*Bio::Emboss::Str::ajStrSet = *Bio::Emboss::ajStrSet;
*Bio::Emboss::Str::ajStrSetC = *Bio::Emboss::ajStrSetC;
*Bio::Emboss::Str::ajStrSize = *Bio::Emboss::ajStrSize;
*Bio::Emboss::Str::ajStrStr = *Bio::Emboss::ajStrStr;
*Bio::Emboss::Str::ajStrStrMod = *Bio::Emboss::ajStrStrMod;
*Bio::Emboss::Str::ajStrSub = *Bio::Emboss::ajStrSub;
*Bio::Emboss::Str::ajStrSubstitute = *Bio::Emboss::ajStrSubstitute;
*Bio::Emboss::Str::ajStrSubstituteCC = *Bio::Emboss::ajStrSubstituteCC;
*Bio::Emboss::Str::ajStrSubstituteKK = *Bio::Emboss::ajStrSubstituteKK;
*Bio::Emboss::Str::ajStrSuffix = *Bio::Emboss::ajStrSuffix;
*Bio::Emboss::Str::ajStrSuffixC = *Bio::Emboss::ajStrSuffixC;
*Bio::Emboss::Str::ajStrToBool = *Bio::Emboss::ajStrToBool;
*Bio::Emboss::Str::ajStrToDouble = *Bio::Emboss::ajStrToDouble;
*Bio::Emboss::Str::ajStrToFloat = *Bio::Emboss::ajStrToFloat;
*Bio::Emboss::Str::ajStrToHex = *Bio::Emboss::ajStrToHex;
*Bio::Emboss::Str::ajStrToInt = *Bio::Emboss::ajStrToInt;
*Bio::Emboss::Str::ajStrTok = *Bio::Emboss::ajStrTok;
*Bio::Emboss::Str::ajStrTokC = *Bio::Emboss::ajStrTokC;
*Bio::Emboss::Str::ajStrToken = *Bio::Emboss::ajStrToken;
*Bio::Emboss::Str::ajStrTokenCount = *Bio::Emboss::ajStrTokenCount;
*Bio::Emboss::Str::ajStrTokenCountR = *Bio::Emboss::ajStrTokenCountR;
*Bio::Emboss::Str::ajStrTokenInit = *Bio::Emboss::ajStrTokenInit;
*Bio::Emboss::Str::ajStrTokenRest = *Bio::Emboss::ajStrTokenRest;
*Bio::Emboss::Str::ajStrToLong = *Bio::Emboss::ajStrToLong;
*Bio::Emboss::Str::ajStrToLower = *Bio::Emboss::ajStrToLower;
*Bio::Emboss::Str::ajStrToLowerII = *Bio::Emboss::ajStrToLowerII;
*Bio::Emboss::Str::ajStrToTitle = *Bio::Emboss::ajStrToTitle;
*Bio::Emboss::Str::ajStrToUpper = *Bio::Emboss::ajStrToUpper;
*Bio::Emboss::Str::ajStrToUpperII = *Bio::Emboss::ajStrToUpperII;
*Bio::Emboss::Str::ajStrTrace = *Bio::Emboss::ajStrTrace;
*Bio::Emboss::Str::ajStrTraceChars = *Bio::Emboss::ajStrTraceChars;
*Bio::Emboss::Str::ajStrTraceT = *Bio::Emboss::ajStrTraceT;
*Bio::Emboss::Str::ajStrTrim = *Bio::Emboss::ajStrTrim;
*Bio::Emboss::Str::ajStrTrimC = *Bio::Emboss::ajStrTrimC;
*Bio::Emboss::Str::ajStrTrimEndC = *Bio::Emboss::ajStrTrimEndC;
*Bio::Emboss::Str::ajStrTrimStartC = *Bio::Emboss::ajStrTrimStartC;
*Bio::Emboss::Str::ajStrTruncate = *Bio::Emboss::ajStrTruncate;
*Bio::Emboss::Str::ajStrWhole = *Bio::Emboss::ajStrWhole;
*Bio::Emboss::Str::ajStrWildPrefix = *Bio::Emboss::ajStrWildPrefix;
*Bio::Emboss::Str::ajStrWrap = *Bio::Emboss::ajStrWrap;
*Bio::Emboss::Str::ajStrWrapLeft = *Bio::Emboss::ajStrWrapLeft;
*Bio::Emboss::Str::ajStrUncomment = *Bio::Emboss::ajStrUncomment;
*Bio::Emboss::Str::ajStrUncommentStart = *Bio::Emboss::ajStrUncommentStart;
*Bio::Emboss::Str::ajTrnNew = *Bio::Emboss::ajTrnNew;
*Bio::Emboss::Str::ajUtilUid = *Bio::Emboss::ajUtilUid;
*Bio::Emboss::Str::ajXyzPdbtospBinSearch = *Bio::Emboss::ajXyzPdbtospBinSearch;
*Bio::Emboss::Str::ajXyzPdbToSp = *Bio::Emboss::ajXyzPdbToSp;
*Bio::Emboss::Str::ajXyzPdbToAcc = *Bio::Emboss::ajXyzPdbToAcc;
*Bio::Emboss::Str::ajXyzScopToPdb = *Bio::Emboss::ajXyzScopToPdb;
*Bio::Emboss::Str::ajXyzScopToSp = *Bio::Emboss::ajXyzScopToSp;
*Bio::Emboss::Str::ajXyzScopToAcc = *Bio::Emboss::ajXyzScopToAcc;
*Bio::Emboss::Str::ajXyzHitidxBinSearch = *Bio::Emboss::ajXyzHitidxBinSearch;
*Bio::Emboss::Str::embDbiFileIn = *Bio::Emboss::embDbiFileIn;
*Bio::Emboss::Str::embDbiFileIndex = *Bio::Emboss::embDbiFileIndex;
*Bio::Emboss::Str::embDbiFileList = *Bio::Emboss::embDbiFileList;
*Bio::Emboss::Str::embDbiFileListExc = *Bio::Emboss::embDbiFileListExc;
*Bio::Emboss::Str::embDbiFileOut = *Bio::Emboss::embDbiFileOut;
*Bio::Emboss::Str::embDbiFileSingle = *Bio::Emboss::embDbiFileSingle;
*Bio::Emboss::Str::embDbiFlatOpenlib = *Bio::Emboss::embDbiFlatOpenlib;
*Bio::Emboss::Str::embDbiMaxlen = *Bio::Emboss::embDbiMaxlen;
*Bio::Emboss::Str::embDbiRmEntryFile = *Bio::Emboss::embDbiRmEntryFile;
*Bio::Emboss::Str::embDbiRmFile = *Bio::Emboss::embDbiRmFile;
*Bio::Emboss::Str::embDbiRmFileI = *Bio::Emboss::embDbiRmFileI;
*Bio::Emboss::Str::embDbiSortFile = *Bio::Emboss::embDbiSortFile;
*Bio::Emboss::Str::embDbiSysCmd = *Bio::Emboss::embDbiSysCmd;
*Bio::Emboss::Str::embScopToPdbid = *Bio::Emboss::embScopToPdbid;
*Bio::Emboss::Str::embScopToSp = *Bio::Emboss::embScopToSp;
*Bio::Emboss::Str::embScopToAcc = *Bio::Emboss::embScopToAcc;
*Bio::Emboss::Str::embBtreeEmblAC = *Bio::Emboss::embBtreeEmblAC;
*Bio::Emboss::Str::embBtreeEmblKW = *Bio::Emboss::embBtreeEmblKW;
*Bio::Emboss::Str::embBtreeEmblDE = *Bio::Emboss::embBtreeEmblDE;
*Bio::Emboss::Str::embBtreeGenBankAC = *Bio::Emboss::embBtreeGenBankAC;
*Bio::Emboss::Str::embBtreeGenBankKW = *Bio::Emboss::embBtreeGenBankKW;
*Bio::Emboss::Str::embBtreeGenBankDE = *Bio::Emboss::embBtreeGenBankDE;
*Bio::Emboss::Str::embBtreeGenBankTX = *Bio::Emboss::embBtreeGenBankTX;
*Bio::Emboss::Str::embBtreeFastaDE = *Bio::Emboss::embBtreeFastaDE;
*Bio::Emboss::Str::embBtreeReadDir = *Bio::Emboss::embBtreeReadDir;
*Bio::Emboss::Str::embMatProtScanInt = *Bio::Emboss::embMatProtScanInt;
*Bio::Emboss::Str::embMiscMatchPattern = *Bio::Emboss::embMiscMatchPattern;
*Bio::Emboss::Str::embMolGetFrags = *Bio::Emboss::embMolGetFrags;
*Bio::Emboss::Str::embNmerInt2nuc = *Bio::Emboss::embNmerInt2nuc;
*Bio::Emboss::Str::embNmerInt2prot = *Bio::Emboss::embNmerInt2prot;
*Bio::Emboss::Str::embPdbidToSp = *Bio::Emboss::embPdbidToSp;
*Bio::Emboss::Str::embPdbidToAcc = *Bio::Emboss::embPdbidToAcc;
*Bio::Emboss::Str::embStrideToThree = *Bio::Emboss::embStrideToThree;
*Bio::Emboss::Str::embShowUpperRange = *Bio::Emboss::embShowUpperRange;
*Bio::Emboss::Str::embShowColourRange = *Bio::Emboss::embShowColourRange;

*Bio::Emboss::StrTok::ajStrTokenAss = *Bio::Emboss::ajStrTokenAss;
*Bio::Emboss::StrTok::ajStrTokenClear = *Bio::Emboss::ajStrTokenClear;
*Bio::Emboss::StrTok::ajStrTokenReset = *Bio::Emboss::ajStrTokenReset;
*Bio::Emboss::StrTok::ajStrTokenTrace = *Bio::Emboss::ajStrTokenTrace;

*Bio::Emboss::Table::embWordBuildMatchTable = *Bio::Emboss::embWordBuildMatchTable;
*Bio::Emboss::Table::embWordFreeTable = *Bio::Emboss::embWordFreeTable;
*Bio::Emboss::Table::embWordGetTable = *Bio::Emboss::embWordGetTable;
*Bio::Emboss::Table::embWordPrintTable = *Bio::Emboss::embWordPrintTable;
*Bio::Emboss::Table::embWordPrintTableF = *Bio::Emboss::embWordPrintTableF;

*Bio::Emboss::Time::ajTimeTrace = *Bio::Emboss::ajTimeTrace;
*Bio::Emboss::Time::ajTimeDel = *Bio::Emboss::ajTimeDel;

*Bio::Emboss::Tree::ajTreeAddData = *Bio::Emboss::ajTreeAddData;
*Bio::Emboss::Tree::ajTreeAddNode = *Bio::Emboss::ajTreeAddNode;
*Bio::Emboss::Tree::ajTreeAddSubNode = *Bio::Emboss::ajTreeAddSubNode;
*Bio::Emboss::Tree::ajTreeCopy = *Bio::Emboss::ajTreeCopy;
*Bio::Emboss::Tree::ajTreeDel = *Bio::Emboss::ajTreeDel;
*Bio::Emboss::Tree::ajTreeFree = *Bio::Emboss::ajTreeFree;
*Bio::Emboss::Tree::ajTreeLength = *Bio::Emboss::ajTreeLength;
*Bio::Emboss::Tree::ajTreestrCopy = *Bio::Emboss::ajTreestrCopy;
*Bio::Emboss::Tree::ajTreestrDel = *Bio::Emboss::ajTreestrDel;
*Bio::Emboss::Tree::ajTreestrFree = *Bio::Emboss::ajTreestrFree;
*Bio::Emboss::Tree::ajTreestrToArray = *Bio::Emboss::ajTreestrToArray;
*Bio::Emboss::Tree::ajTreeTrace = *Bio::Emboss::ajTreeTrace;

*Bio::Emboss::Trn::ajTrnDel = *Bio::Emboss::ajTrnDel;
*Bio::Emboss::Trn::ajTrnReadFile = *Bio::Emboss::ajTrnReadFile;
*Bio::Emboss::Trn::ajTrnCodon = *Bio::Emboss::ajTrnCodon;
*Bio::Emboss::Trn::ajTrnRevCodon = *Bio::Emboss::ajTrnRevCodon;
*Bio::Emboss::Trn::ajTrnCodonC = *Bio::Emboss::ajTrnCodonC;
*Bio::Emboss::Trn::ajTrnRevCodonC = *Bio::Emboss::ajTrnRevCodonC;
*Bio::Emboss::Trn::ajTrnCodonK = *Bio::Emboss::ajTrnCodonK;
*Bio::Emboss::Trn::ajTrnRevCodonK = *Bio::Emboss::ajTrnRevCodonK;
*Bio::Emboss::Trn::ajTrnC = *Bio::Emboss::ajTrnC;
*Bio::Emboss::Trn::ajTrnRevC = *Bio::Emboss::ajTrnRevC;
*Bio::Emboss::Trn::ajTrnAltRevC = *Bio::Emboss::ajTrnAltRevC;
*Bio::Emboss::Trn::ajTrnStr = *Bio::Emboss::ajTrnStr;
*Bio::Emboss::Trn::ajTrnRevStr = *Bio::Emboss::ajTrnRevStr;
*Bio::Emboss::Trn::ajTrnAltRevStr = *Bio::Emboss::ajTrnAltRevStr;
*Bio::Emboss::Trn::ajTrnSeq = *Bio::Emboss::ajTrnSeq;
*Bio::Emboss::Trn::ajTrnRevSeq = *Bio::Emboss::ajTrnRevSeq;
*Bio::Emboss::Trn::ajTrnAltRevSeq = *Bio::Emboss::ajTrnAltRevSeq;
*Bio::Emboss::Trn::ajTrnCFrame = *Bio::Emboss::ajTrnCFrame;
*Bio::Emboss::Trn::ajTrnStrFrame = *Bio::Emboss::ajTrnStrFrame;
*Bio::Emboss::Trn::ajTrnSeqFrame = *Bio::Emboss::ajTrnSeqFrame;
*Bio::Emboss::Trn::ajTrnSeqFramePep = *Bio::Emboss::ajTrnSeqFramePep;
*Bio::Emboss::Trn::ajTrnCDangle = *Bio::Emboss::ajTrnCDangle;
*Bio::Emboss::Trn::ajTrnStrDangle = *Bio::Emboss::ajTrnStrDangle;
*Bio::Emboss::Trn::ajTrnGetTitle = *Bio::Emboss::ajTrnGetTitle;
*Bio::Emboss::Trn::ajTrnGetFileName = *Bio::Emboss::ajTrnGetFileName;
*Bio::Emboss::Trn::ajTrnStartStop = *Bio::Emboss::ajTrnStartStop;
*Bio::Emboss::Trn::ajTrnStartStopC = *Bio::Emboss::ajTrnStartStopC;
*Bio::Emboss::Trn::ajTrnSeqOrig = *Bio::Emboss::ajTrnSeqOrig;

*Bio::Emboss::Vdwall::ajVdwallDel = *Bio::Emboss::ajVdwallDel;
*Bio::Emboss::Vdwall::ajXyzVdwallDel = *Bio::Emboss::ajXyzVdwallDel;

*Bio::Emboss::Vdwres::ajVdwresDel = *Bio::Emboss::ajVdwresDel;
*Bio::Emboss::Vdwres::ajXyzVdwresDel = *Bio::Emboss::ajXyzVdwresDel;

# --- list all methods of EMBOSS for the EXPORT :all tag

@ALL_METHODS = qw(
	embInitPerl
	ajGraphInitPerl
	ajAcdDebug
	ajAcdDebugIsSet
	ajAcdExit
	ajAcdFilter
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetCpdb
	ajAcdGetDatafile
	ajAcdGetDirectory
	ajAcdGetDirectoryName
	ajAcdGetDirlist
	ajAcdGetDiscretestates
	ajAcdGetDiscretestatesI
	ajAcdGetDistances
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetFrequencies
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListI
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutcodon
	ajAcdGetOutcpdb
	ajAcdGetOutdata
	ajAcdGetOutdir
	ajAcdGetOutdirName
	ajAcdGetOutdiscrete
	ajAcdGetOutdistance
	ajAcdGetOutfile
	ajAcdGetOutfileall
	ajAcdGetOutfreq
	ajAcdGetOutmatrix
	ajAcdGetOutmatrixf
	ajAcdGetOutproperties
	ajAcdGetOutscop
	ajAcdGetOuttree
	ajAcdGetProperties
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectI
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetSeqsetall
	ajAcdGetSeqsetallI
	ajAcdGetString
	ajAcdGetToggle
	ajAcdGetTree
	ajAcdGetTreeI
	ajAcdPrintType
	ajAcdPrintQual
	ajAcdProgram
	ajAcdProgramS
	ajAcdSetControl
	ajAcdStdout
	ajAcdValue
	ajAlignClose
	ajAlignConsStats
	ajAlignDefine
	ajAlignDefineSS
	ajAlignDefineCC
	ajAlignDel
	ajAlignOpen
	ajAlignFindFormat
	ajAlignFormatDefault
	ajAlignNew
	ajAlignPrintFormat
	ajAlignReset
	ajAlignSetHeader
	ajAlignSetHeaderApp
	ajAlignSetHeaderC
	ajAlignSetGapI
	ajAlignSetGapR
	ajAlignSetMatrixName
	ajAlignSetMatrixNameC
	ajAlignSetMatrixInt
	ajAlignSetMatrixFloat
	ajAlignSetRange
	ajAlignSetScoreI
	ajAlignSetScoreR
	ajAlignSetSubHeader
	ajAlignSetSubHeaderApp
	ajAlignSetSubHeaderC
	ajAlignSetSubHeaderPre
	ajAlignSetStats
	ajAlignSetSubRange
	ajAlignSetSubStandard
	ajAlignSetTail
	ajAlignSetTailApp
	ajAlignSetTailC
	ajAlignSetType
	ajAlignTrace
	ajAlignTraceT
	ajAlignValid
	ajAlignWrite
	ajAlignWriteHeader
	ajAlignWriteTail
	ajCodAssCode
	ajCodAssDesc
	ajCodAssDescC
	ajCodAssDivision
	ajCodAssDivisionC
	ajCodAssNumcds
	ajCodAssNumcodon
	ajCodAssRelease
	ajCodAssReleaseC
	ajCodAssSpecies
	ajCodAssSpeciesC
	ajCodAssName
	ajCodAssNameC
	ajCodBacktranslate
	ajCodBase
	ajCodCai
	ajCodCalcGribskov
	ajCodCalcCai
	ajCodCalcNc
	ajCodCalculateUsage
	ajCodClear
	ajCodClearData
	ajCodComp
	ajCodCountTriplets
	ajCodDel
	ajCodDup
	ajCodGetCode
	ajCodGetDesc
	ajCodGetDescC
	ajCodGetDivision
	ajCodGetDivisionC
	ajCodGetName
	ajCodGetNameC
	ajCodGetNumcds
	ajCodGetNumcodon
	ajCodGetRelease
	ajCodGetReleaseC
	ajCodGetSpecies
	ajCodGetSpeciesC
	ajCodIndex
	ajCodIndexC
	ajCodNew
	ajCodNewCode
	ajCodRead
	ajCodSetBacktranslate
	ajCodTriplet
	ajCodWrite
	ajCodWriteOut
	ajCodOutFormat
	ajDmxDummyFunction
	ajDmxScophitNew
	ajDmxScophitDel
	ajDmxScophitListCopy
	ajDmxScophitCheckTarget
	ajDmxScophitTarget
	ajDmxScophitTarget2
	ajDmxScophitTargetLowPriority
	ajDmxScophitCompSpr
	ajDmxScophitCompStart
	ajDmxScophitCompEnd
	ajDmxScophitCompFold
	ajDmxScophitCompSfam
	ajDmxScophitCompFam
	ajDmxScophitCompAcc
	ajDmxScophitCompSunid
	ajDmxScophitCompScore
	ajDmxScophitCompPval
	ajDmxScopSeqFromSunid
	ajDmxScophitsWrite
	ajDmxScophitsWriteFasta
	ajDmxScophitReadFasta
	ajDmxScophitCopy
	ajDmxScopalgRead
	ajDmxScopalgWrite
	ajDmxScopalgWriteClustal
	ajDmxScopalgWriteClustal2
	ajDmxScopalgWriteFasta
	ajDmxScopalgNew
	ajDmxScopalgDel
	ajScopNew
	ajScopDel
	ajScopCopy
	ajScopArrFindScopid
	ajScopArrFindSunid
	ajScopArrFindPdbid
	ajScopMatchScopid
	ajScopMatchPdbId
	ajScopMatchSunid
	ajScopReadCNew
	ajScopReadNew
	ajScopReadAllNew
	ajScopReadAllRawNew
	ajScopWrite
	ajPdbWriteDomain
	ajCathNew
	ajCathDel
	ajCathCopy
	ajCathArrFindPdbid
	ajCathReadCNew
	ajCathReadNew
	ajCathReadAllNew
	ajCathReadAllRawNew
	ajCathWrite
	ajDomainNew
	ajDomainReadNew
	ajDomainReadCNew
	ajDomainReadAllNew
	ajDomainDel
	ajDomainWrite
	ajDomainDCFType
	ajDomainCopy
	ajDomainGetId
	ajDomainGetSeqPdb
	ajDomainGetSeqSpr
	ajDomainGetPdb
	ajDomainGetAcc
	ajDomainGetSpr
	ajDomainGetN
	ajFeatIsChild
	ajFeatCopy
	ajFeatDel
	ajFeatExit
	ajFeatGetEnd
	ajFeatGetForward
	ajFeatGetFrame
	ajFeatGetNote
	ajFeatGetNoteI
	ajFeatGetStart
	ajFeatGetTag
	ajFeatGetType
	ajFeatIsCompMult
	ajFeatIsLocal
	ajFeatIsLocalRange
	ajFeatIsMultiple
	ajFeatLocToSeq
	ajFeatNew
	ajFeatNewII
	ajFeatNewIIRev
	ajFeatNewProt
	ajFeatOutFormatDefault
	ajFeatRead
	ajFeatReverse
	ajFeatSetDesc
	ajFeatSetDescApp
	ajFeatSortByEnd
	ajFeatSortByStart
	ajFeatSortByType
	ajFeattableAdd
	ajFeattableBegin
	ajFeattableClear
	ajFeattableCopy
	ajFeattableDel
	ajFeattableEnd
	ajFeattableGetName
	ajFeattableIsNuc
	ajFeattableIsProt
	ajFeattableLen
	ajFeattableNew
	ajFeattableNewDna
	ajFeattableNewProt
	ajFeattableNewSeq
	ajFeattablePos
	ajFeattablePosI
	ajFeattablePosII
	ajFeattableReverse
	ajFeattableSetDna
	ajFeattableSetProt
	ajFeattableSetRange
	ajFeattableSize
	ajFeattableTrace
	ajFeattableTrimOff
	ajFeattableWrite
	ajFeattableWriteDdbj
	ajFeattableWriteEmbl
	ajFeattableWriteGenbank
	ajFeattableWriteGff
	ajFeattableWritePir
	ajFeattableWriteSwiss
	ajFeattabInClear
	ajFeattabInDel
	ajFeattabInNew
	ajFeattabInNewSS
	ajFeattabInNewSSF
	ajFeattabInSetType
	ajFeattabInSetTypeC
	ajFeattabOutDel
	ajFeattabOutFile
	ajFeattabOutFilename
	ajFeattabOutIsLocal
	ajFeattabOutIsOpen
	ajFeattabOutNew
	ajFeattabOutNewSSF
	ajFeattabOutOpen
	ajFeattabOutSet
	ajFeattabOutSetBasename
	ajFeattabOutSetType
	ajFeattabOutSetTypeC
	ajFeatTagAdd
	ajFeatTagAddC
	ajFeatTagAddCC
	ajFeatTagIter
	ajFeatTagSet
	ajFeatTagSetC
	ajFeatTagTrace
	ajFeatTagval
	ajFeatTest
	ajFeatTrace
	ajFeatTrimOffRange
	ajFeatUfoRead
	ajFeatUfoWrite
	ajFeatWrite
	ajDirDel
	ajDiroutDel
	ajDirExt
	ajDirName
	ajDirNew
	ajDirNewS
	ajDirNewSS
	ajDiroutNew
	ajDiroutNewS
	ajDiroutNewSS
	ajFileBuffBuff
	ajFileBuffClear
	ajFileBuffClearStore
	ajFileBuffDel
	ajFileBuffEmpty
	ajFileBuffEnd
	ajFileBuffEof
	ajFileBuffFile
	ajFileBuffFix
	ajFileBuffFp
	ajFileBuffFreeClear
	ajFileBuffGet
	ajFileBuffGetL
	ajFileBuffGetStore
	ajFileBuffGetStoreL
	ajFileBuffIsBuffered
	ajFileBuffLoad
	ajFileBuffLoadC
	ajFileBuffLoadS
	ajFileBuffNew
	ajFileBuffNewDC
	ajFileBuffNewDF
	ajFileBuffNewDW
	ajFileBuffNewDWE
	ajFileBuffNewF
	ajFileBuffNewFile
	ajFileBuffNewIn
	ajFileBuffNewInList
	ajFileBuffNewS
	ajFileBuffNobuff
	ajFileBuffPrint
	ajFileBuffReset
	ajFileBuffResetPos
	ajFileBuffResetStore
	ajFileBuffSetFile
	ajFileBuffSize
	ajFileBuffStripHtml
	ajFileBuffStripHtmlPre
	ajFileBuffTrace
	ajFileBuffTraceFull
	ajFileClose
	ajFileDataDirNew
	ajFileDataDirNewC
	ajFileDataNew
	ajFileDataNewC
	ajFileDataNewWrite
	ajFileDir
	ajFileDirFix
	ajFileDirUp
	ajFileDirPath
	ajFileDirTrim
	ajFileExtnTrim
	ajFileDirExtnTrim
	ajFileEof
	ajFileExit
	ajFileFileList
	ajFileFp
	ajFileGetwd
	ajFileGetName
	ajFileGets
	ajFileGetsL
	ajFileGetsTrim
	ajFileGetsTrimL
	ajFileHasDir
	ajFileLength
	ajFileName
	ajFileNameDir
	ajFileNameDirSet
	ajFileNameDirSetC
	ajFileNameExt
	ajFileNameExtC
	ajFileNameShorten
	ajFileNameTrim
	ajFileNew
	ajFileNewApp
	ajFileNewDirF
	ajFileNewDC
	ajFileNewDF
	ajFileNewDW
	ajFileNewDWE
	ajFileNewF
	ajFileNewIn
	ajFileNewInC
	ajFileNewInPipe
	ajFileNewInList
	ajFileNewOut
	ajFileNewOutC
	ajFileNewOutD
	ajFileNewOutDir
	ajFileOutHeader
	ajFileOutClose
	ajFileNext
	ajFileRead
	ajFileReadAppend
	ajFileReadLine
	ajFileReadUint
	ajFileReopen
	ajFileScan
	ajFileSeek
	ajFileSetDir
	ajFileStat
	ajFileStderr
	ajFileStdin
	ajFileStdout
	ajFileTell
	ajFileTempName
	ajFileTestSkip
	ajFileTrace
	ajFileUnbuffer
	ajFileWrite
	ajFileWriteByte
	ajFileWriteChar
	ajFileWriteInt2
	ajFileWriteInt4
	ajFileWriteInt8
	ajFileWriteStr
	ajOutfileClose
	ajOutfileDel
	ajOutfileFile
	ajOutfileFormat
	ajOutfileFp
	ajOutfileNew
	ajGraphBox
	ajGraphBoxFill
	ajGraphCheckColour
	ajGraphCircle
	ajGraphClose
	ajGraphCloseWin
	ajGraphColourBack
	ajGraphColourFore
	ajGraphPlpDataAddLine
	ajGraphPlpDataAddRect
	ajGraphPlpDataAddText
	ajGraphPlpDataSetMaxMin
	ajGraphArrayMaxMin
	ajGraphPlpDataSetMaxima
	ajGraphPlpDataSetTypeC
	ajGraphPlpDataTrace
	ajGraphClear
	ajGraphDia
	ajGraphDiaFill
	ajGraphDots
	ajGraphDumpDevices
	ajGraphGetCharSize
	ajGraphGetColour
	ajGraphGetOut
	ajGraphGetSubTitle
	ajGraphGetSubTitleC
	ajGraphGetTitle
	ajGraphGetTitleC
	ajGraphGetXTitle
	ajGraphGetXTitleC
	ajGraphGetYTitle
	ajGraphGetYTitleC
	ajGraphHoriBars
	ajGraphInfo
	ajGraphInitSeq
	ajGraphIsData
	ajGraphLabel
	ajGraphLabelYRight
	ajGraphLine
	ajGraphLines
	ajGraphNew
	ajGraphNewPage
	ajGraphAddLine
	ajGraphAddRect
	ajGraphAddText
	ajGraphPlpDataDel
	ajGraphOpen
	ajGraphOpenPlot
	ajGraphOpenWin
	ajGraphPlenv
	ajGraphPoly
	ajGraphPolyFill
	ajGraphPrintType
	ajGraphRect
	ajGraphRectFill
	ajGraphSet
	ajGraphSetDevice
	ajGraphSetCharSize
	ajGraphSetBackBlack
	ajGraphSetBackWhite
	ajGraphSetPenWidth
	ajGraphSetFillPat
	ajGraphSetFore
	ajGraphSetLineStyle
	ajGraphSetMulti
	ajGraphSetName
	ajGraphSetOri
	ajGraphSymbols
	ajGraphText
	ajGraphTextEnd
	ajGraphTextMid
	ajGraphTextLine
	ajGraphTextStart
	ajGraphTrace
	ajGraphTraceInt
	ajGraphTri
	ajGraphTriFill
	ajGraphUnused
	ajGraphVertBars
	ajGraphPlpDataCalcXY
	ajGraphPlpDataSetXY
	ajGraphDataAdd
	ajGraphDataReplace
	ajGraphPlpDataNew
	ajGraphPlpDataNewI
	ajGraphPlpDataSetSubTitle
	ajGraphPlpDataSetSubTitleC
	ajGraphPlpDataSetTitle
	ajGraphPlpDataSetTitleC
	ajGraphPlpDataSetXTitle
	ajGraphPlpDataSetXTitleC
	ajGraphPlpDataSetYTitle
	ajGraphPlpDataSetYTitleC
	ajGraphxyDel
	ajGraphxyDisplay
	ajGraphxyNewI
	ajGraphxyCheckMaxMin
	ajGraphxySet
	ajGraphxySetCirclePoints
	ajGraphPlpDataSetColour
	ajGraphSetFlag
	ajGraphxySetGaps
	ajGraphxySetJoinPoints
	ajGraphPlpDataSetLineType
	ajGraphxySetMaxMin
	ajGraphSetOut
	ajGraphSetOutC
	ajGraphxySetOverLap
	ajGraphSetSubTitleDo
	ajGraphSetTitleDo
	ajGraphxySetXBottom
	ajGraphxySetXLabelTop
	ajGraphxySetXTick
	ajGraphxySetXTop
	ajGraphxySetXEnd
	ajGraphxySetXGrid
	ajGraphxySetXInvTicks
	ajGraphxySetXLabel
	ajGraphxySetXRangeII
	ajGraphxySetXStart
	ajGraphxySetYLabelLeft
	ajGraphxySetYLeft
	ajGraphxySetYRight
	ajGraphxySetYTick
	ajGraphxySetYEnd
	ajGraphxySetYGrid
	ajGraphxySetYInvTicks
	ajGraphxySetYLabel
	ajGraphxySetYRangeII
	ajGraphxySetYStart
	ajGraphSetSubTitle
	ajGraphSetSubTitleC
	ajGraphSetTitle
	ajGraphSetTitleC
	ajGraphSetXTitle
	ajGraphSetXTitleC
	ajGraphSetYTitle
	ajGraphSetYTitleC
	ajGraphPartCircle
	ajGraphDrawTextOnCurve
	ajGraphRectangleOnCurve
	ajGraphTextLength
	ajGraphTextHeight
	ajGraphDistPts
	ajGraphFitTextOnLine
	ajGraphSetDefCharSize
	ajGraphFillRectangleOnCurve
	ajHistClose
	ajHistCopyData
	ajHistDelete
	ajHistDisplay
	ajHistNew
	ajHistNewG
	ajHistSetBlackandWhite
	ajHistSetColour
	ajHistSetMultiTitle
	ajHistSetMultiTitleC
	ajHistSetMultiXTitle
	ajHistSetMultiXTitleC
	ajHistSetMultiYTitle
	ajHistSetMultiYTitleC
	ajHistSetPattern
	ajHistSetPtrToData
	ajHistSetTitleC
	ajHistSetXAxisC
	ajHistSetYAxisLeftC
	ajHistSetYAxisRightC
	ajBtreeCacheNewC
	ajBtreeCacheRead
	ajBtreeCacheWrite
	ajBtreeCreateRootNode
	ajBtreeFindInsert
	ajBtreeCacheDel
	ajBtreeInsertId
	ajBtreeIdDel
	ajBtreeIdNew
	ajBtreeIdFromKey
	ajBtreeWriteParams
	ajBtreeReadParams
	ajBtreeCacheSync
	ajBtreeDeleteId
	ajBtreeWildNew
	ajBtreeKeyWildNew
	ajBtreeWildDel
	ajBtreeKeyWildDel
	ajBtreeFindInsertW
	ajBtreeIdFromKeyW
	ajBtreeListFromKeyW
	ajBtreeIdFromKeywordW
	ajBtreeListFromKeywordW
	ajBtreeReplaceId
	ajBtreeReadEntries
	ajBtreeInsertDupId
	ajBtreeDupFromKey
	ajBtreePriNew
	ajBtreePriDel
	ajBtreePriFromKeyword
	ajBtreeSecCacheNewC
	ajBtreeSecFindInsert
	ajBtreeInsertSecId
	ajBtreeSecFromId
	ajBtreeSecLeafList
	ajBtreeVerifyId
	ajBtreeInsertKeyword
	ajBtreeLockTest
	ajListAppend
	ajListCopy
	ajListDel
	ajListExit
	ajListFree
	ajListInsert
	ajListIter
	ajListIterBack
	ajListIterBackRead
	ajListIterRead
	ajListIterBackDone
	ajListIterBackMore
	ajListIterBackNext
	ajListIterFree
	ajListIterNext
	ajListIterMore
	ajListIterDone
	ajListIterTrace
	ajListLength
	ajListNew
	ajListPush
	ajListPushApp
	ajListReverse
	ajListstrCopy
	ajListstrDel
	ajListstrFree
	ajListstrIterTrace
	ajListstrLength
	ajListstrNew
	ajListstrPeek
	ajListstrPop
	ajListstrPopEnd
	ajListstrPush
	ajListstrPushApp
	ajListstrReverse
	ajListstrToArray
	ajListstrToArrayApp
	ajListstrTrace
	ajListTrace
	ajListPushList
	ajListstrPushList
	ajListRemove
	ajListstrClone
	ajListstrInsert
	ajListstrRemove
	ajDegToRad
	ajGaussProb
	ajGeoMean
	ajPolToRec
	ajPosMod
	ajRadToDeg
	ajRandomNumber
	ajRandomNumberD
	ajRandomSeed
	ajRecToPol
	ajRound
	ajRoundF
	ajMatrixChar
	ajMatrixCvt
	ajMatrixDel
	ajMatrixName
	ajMatrixSeqNum
	ajMatrixRead
	ajMatrixSize
	ajMatrixfChar
	ajMatrixfCvt
	ajMatrixfDel
	ajMatrixfName
	ajMatrixfSeqNum
	ajMatrixfRead
	ajMatrixfSize
	ajMemAlloc
	ajMemCalloc
	ajMemCalloc0
	ajMemFree
	ajMemResize
	ajMemStat
	ajMemExit
	ajMessCrashCodeFL
	ajMessErrorInit
	ajMessBeep
	ajMessErrorSetFile
	ajMessCodesDelete
	ajMessOutCode
	ajMessErrorCode
	ajMessExit
	ajMessSetErr
	ajDebugFile
	ajMessSysErrorText
	ajMessErrorCount
	ajMessCaughtMessage
	ajNamDatabase
	ajNamDbDetails
	ajNamDbGetDbalias
	ajNamDbGetUrl
	ajNamDbData
	ajNamDbQuery
	ajNamDbTest
	ajNamDebugOrigin
	ajNamDebugDatabases
	ajNamDebugResources
	ajNamDebugVariables
	ajNamExit
	ajNamGetenv
	ajNamGetenvC
	ajNamGetValue
	ajNamGetValueC
	ajNamInit
	ajNamIsDbname
	ajNamListDatabases
	ajNamListListDatabases
	ajNamListListResources
	ajNamListOrigin
	ajNamPrintDbAttr
	ajNamPrintRsAttr
	ajNamResolve
	ajNamRoot
	ajNamRootBase
	ajNamRootInstall
	ajNamRootPack
	ajNamRootVersion
	ajNamRsAttrValue
	ajNamRsAttrValueC
	ajNamRsListValue
	ajNamSetControl
	ajNamVariables
	ajNexusDel
	ajNexusGetNtaxa
	ajNexusGetTaxa
	ajNexusGetSequences
	ajNexusNew
	ajNexusParse
	ajNexusTrace
	ajHetNew
	ajHetDel
	ajHetentNew
	ajHetentDel
	ajVdwallNew
	ajVdwallDel
	ajVdwresNew
	ajVdwresDel
	ajAtomNew
	ajAtomDel
	ajAtomCopy
	ajAtomListCopy
	ajAtomEnv13
	ajResidueNew
	ajResidueDel
	ajPdbtospNew
	ajPdbtospDel
	ajPdbtospArrFindPdbid
	ajChainNew
	ajChainDel
	ajPdbNew
	ajPdbDel
	ajPdbCopy
	ajPdbChnidToNum
	ajPdbReadNew
	ajPdbReadFirstModelNew
	ajPdbWriteAll
	ajPdbWriteSegment
	ajPdbGetEStrideType
	ajHetReadRawNew
	ajHetReadNew
	ajHetWrite
	ajVdwallReadNew
	ajCmapNew
	ajCmapReadCNew
	ajCmapReadINew
	ajCmapReadNew
	ajCmapReadAllNew
	ajCmapDel
	ajCmapWrite
	ajPdbtospReadAllRawNew
	ajPdbtospReadNew
	ajPdbtospReadCNew
	ajPdbtospReadAllNew
	ajPdbtospWrite
	ajPdbReadRawNew
	ajPdbWriteAllRaw
	ajPdbWriteDomainRaw
	ajPdbWriteRecordRaw
	ajPdbWriteDomainRecordRaw
	ajPhyloDistDel
	ajPhyloDistNew
	ajPhyloDistRead
	ajPhyloDistTrace
	ajPhyloFreqDel
	ajPhyloFreqNew
	ajPhyloFreqRead
	ajPhyloFreqTrace
	ajPhyloPropDel
	ajPhyloPropGetSize
	ajPhyloPropNew
	ajPhyloPropRead
	ajPhyloPropTrace
	ajPhyloStateDel
	ajPhyloStateNew
	ajPhyloStateRead
	ajPhyloStateTrace
	ajPhyloTreeDel
	ajPhyloTreeNew
	ajPhyloTreeRead
	ajPhyloTreeTrace
	ajRangeBegin
	ajRangeChange
	ajRangeCopy
	ajRangeDefault
	ajRangeDel
	ajRangeFile
	ajRangeGet
	ajRangeNewI
	ajRangeNumber
	ajRangeOrdered
	ajRangeOverlaps
	ajRangeOverlapSingle
	ajRangeSeqExtract
	ajRangeSeqExtractList
	ajRangeSeqMask
	ajRangeSeqStuff
	ajRangeSeqToLower
	ajRangeStrExtract
	ajRangeStrExtractList
	ajRangeStrMask
	ajRangeStrStuff
	ajRangeStrToLower
	ajRangeText
	ajRangeValues
	ajRegComp
	ajRegCompC
	ajRegCompCase
	ajRegCompCaseC
	ajRegExec
	ajRegExecB
	ajRegExecC
	ajRegLenI
	ajRegOffset
	ajRegOffsetI
	ajRegPre
	ajRegPost
	ajRegSubI
	ajRegFree
	ajRegTrace
	ajRegExit
	ajReportClose
	ajReportDel
	ajReportDummyFunction
	ajReportFileAdd
	ajReportFindFormat
	ajReportFormatDefault
	ajReportNew
	ajReportOpen
	ajReportPrintFormat
	ajReportSeqName
	ajReportSetHeader
	ajReportSetHeaderC
	ajReportSetSubHeader
	ajReportSetSubHeaderC
	ajReportSetTags
	ajReportSetTail
	ajReportSetTailC
	ajReportSetSubTail
	ajReportSetSubTailC
	ajReportSetType
	ajReportValid
	ajReportWrite
	ajReportWriteHeader
	ajReportWriteTail
	ajIsAccession
	ajIsSeqversion
	ajSelexNew
	ajSelexDel
	ajSelexdataNew
	ajSelexdataDel
	ajSelexSQDel
	ajSelexSQNew
	ajStockholmNew
	ajStockholmDel
	ajStockholmdataDel
	ajStockholmdataNew
	ajSeqallBegin
	ajSeqallDel
	ajSeqallEnd
	ajSeqallGetName
	ajSeqallGetNameSeq
	ajSeqallGetRange
	ajSeqallGetUsa
	ajSeqallLen
	ajSeqallNew
	ajSeqallClear
	ajSeqallNext
	ajSeqallReverse
	ajSeqallSetRange
	ajSeqallToLower
	ajSeqallToUpper
	ajSeqAssAcc
	ajSeqAssAccC
	ajSeqAssDesc
	ajSeqAssDescC
	ajSeqAssEntry
	ajSeqAssEntryC
	ajSeqAssFile
	ajSeqAssFull
	ajSeqAssFullC
	ajSeqAssGi
	ajSeqAssGiC
	ajSeqAssName
	ajSeqAssNameC
	ajSeqAssSeq
	ajSeqAssSeqC
	ajSeqAssSeqCI
	ajSeqAssSv
	ajSeqAssSvC
	ajSeqAssUfo
	ajSeqAssUfoC
	ajSeqAssUsa
	ajSeqAssUsaC
	ajSeqBaseComp
	ajSeqBegin
	ajSeqChar
	ajSeqCharCopy
	ajSeqCharCopyL
	ajSeqCheckGcg
	ajSeqClear
	ajSeqCompOnly
	ajSeqGarbageOn
	ajSeqGarbageOff
	ajSeqCompOnlyStr
	ajSeqCopyFeat
	ajSeqCount
	ajSeqCrc
	ajSeqCvtDel
	ajSeqCvtK
	ajSeqCvtKS
	ajSeqCvtKSRow
	ajSeqCvtKSColumn
	ajSeqCvtLen
	ajSeqCvtNew
	ajSeqCvtNewText
	ajSeqCvtNewZero
	ajSeqCvtTrace
	ajSeqDel
	ajSeqEnd
	ajSeqFill
	ajSeqGapCount
	ajSeqGapCountS
	ajSeqGapStandard
	ajSeqGapStandardS
	ajSeqGetAcc
	ajSeqGetDesc
	ajSeqGetEntry
	ajSeqGetFeat
	ajSeqGetGi
	ajSeqGetName
	ajSeqGetRange
	ajSeqGetReverse
	ajSeqGetReversed
	ajSeqGetSv
	ajSeqGetTax
	ajSeqGetUsa
	ajSeqinTrace
	ajSeqIsNuc
	ajSeqIsProt
	ajSeqLen
	ajSeqMakeUsa
	ajSeqMakeUsaS
	ajSeqMod
	ajSeqMW
	ajSeqName
	ajSeqNew
	ajSeqNewC
	ajSeqNewL
	ajSeqNewS
	ajSeqNewRange
	ajSeqNewRangeCI
	ajSeqNewStr
	ajSeqNum
	ajSeqNumS
	ajSeqIsGarbage
	ajSeqIsReversed
	ajSeqIsTrimmed
	ajSeqOffset
	ajSeqOffend
	ajSeqPos
	ajSeqPosI
	ajSeqPosII
	ajSeqReplace
	ajSeqReplaceC
	ajSeqRev
	ajSeqReverse
	ajSeqReverseForce
	ajSeqReverseStr
	ajSeqRevOnly
	ajSeqsetBegin
	ajSeqsetDel
	ajSeqsetEnd
	ajSeqsetFill
	ajSeqsetGetFormat
	ajSeqsetGetName
	ajSeqsetGetRange
	ajSeqsetGetSeq
	ajSeqsetGetUsa
	ajSeqsetIsDna
	ajSeqsetIsNuc
	ajSeqsetIsProt
	ajSeqsetIsRna
	ajSeqsetLen
	ajSeqsetName
	ajSeqsetAcc
	ajSeqsetNew
	ajSeqSetOffsets
	ajSeqSetRange
	ajSeqSetRangeDir
	ajSeqsetReverse
	ajSeqsetSeq
	ajSeqsetSetRange
	ajSeqsetSize
	ajSeqsetToLower
	ajSeqsetTotweight
	ajSeqsetToUpper
	ajSeqsetTrim
	ajSeqsetWeight
	ajSeqStr
	ajSeqStrCopy
	ajSeqToLower
	ajSeqToUpper
	ajSeqTrace
	ajSeqTraceT
	ajSeqFindOutFormat
	ajSeqTrim
	ajSeqTrueBegin
	ajSeqTrueEnd
	ajSeqTrueLen
	ajSeqTruePos
	ajSeqTruePosI
	ajSeqTruePosII
	ajSeqABIGetBaseOffset
	ajSeqABIGetBasePosition
	ajSeqABIGetBasePosOffset
	ajSeqABIGetBaseSpace
	ajSeqABIGetData
	ajSeqABIGetFWO
	ajSeqABIGetNBase
	ajSeqABIGetNData
	ajSeqABIGetPrimerOffset
	ajSeqABIGetPrimerPosition
	ajSeqABIGetSignal
	ajSeqABIGetTraceOffset
	ajSeqABIMachineName
	ajSeqABIReadSeq
	ajSeqABISampleName
	ajSeqABITest
	ajSeqAccessAsis
	ajSeqAccessFile
	ajSeqAccessOffset
	ajSeqMethod
	ajSeqMethodTest
	ajSeqPrintAccess
	ajSeqallFile
	ajSeqAllRead
	ajSeqGetFromUsa
	ajSeqFormatTest
	ajSeqinClear
	ajSeqinClearPos
	ajSeqinDel
	ajSeqinNew
	ajSeqinSetNuc
	ajSeqinSetProt
	ajSeqinSetRange
	ajSeqinUsa
	ajSeqParseFasta
	ajSeqParseNcbi
	ajSeqQueryClear
	ajSeqQueryDel
	ajSeqQueryIs
	ajSeqQueryNew
	ajSeqQueryStarclear
	ajSeqQueryTrace
	ajSeqQueryWild
	ajSeqPrintInFormat
	ajSeqRead
	ajSeqsetApp
	ajSeqsetGetFromUsa
	ajSeqsetFromList
	ajSeqsetFromPair
	ajSeqsetallRead
	ajSeqsetRead
	ajSeqGap
	ajSeqGapLen
	ajSeqGapS
	ajSeqPrintType
	ajSeqSetNuc
	ajSeqSetProt
	ajSeqsetSetNuc
	ajSeqsetSetProt
	ajSeqTypeAnyprotS
	ajSeqTypeDnaS
	ajSeqTypeGapanyS
	ajSeqTypeGapdnaS
	ajSeqTypeGapnucS
	ajSeqTypeGaprnaS
	ajSeqTypeNucS
	ajSeqTypeProtS
	ajSeqTypeRnaS
	ajSeqTypeIsAny
	ajSeqTypeIsNuc
	ajSeqTypeIsProt
	ajSeqType
	ajSeqTypeCheckIn
	ajSeqTypeCheckS
	ajSeqAllWrite
	ajSeqFileNewOut
	ajSeqoutCheckGcg
	ajSeqoutClear
	ajSeqoutDel
	ajSeqOutFormatDefault
	ajSeqOutFormatSingle
	ajSeqoutNew
	ajSeqoutNewF
	ajSeqoutOpen
	ajSeqOutSetFormat
	ajSeqOutSetFormatC
	ajSeqoutTrace
	ajSeqPrintOutFormat
	ajSeqoutUsa
	ajSeqsetWrite
	ajSeqWrite
	ajSeqWriteClose
	ajSeqWriteXyz
	ajSssWriteXyz
	ajCharFree
	ajCharNewC
	ajCharNew
	ajCharNewL
	ajCharNewLS
	ajCharPos
	ajCharToLower
	ajCharToUpper
	ajStrApp
	ajStrAppC
	ajStrAppCI
	ajStrAppK
	ajStrAppKI
	ajStrAppSub
	ajStrArrayDel
	ajStrAss
	ajStrAssC
	ajStrAssCI
	ajStrAssCL
	ajStrAssI
	ajStrAssK
	ajStrAssL
	ajStrAssS
	ajStrAssSub
	ajStrAssSubC
	ajStrBlock
	ajStrBool
	ajStrChar
	ajStrCheck
	ajStrChomp
	ajStrChompC
	ajStrChompEnd
	ajStrChop
	ajStrClean
	ajStrCleanWhite
	ajStrClear
	ajStrCmpC
	ajStrCmpCase
	ajStrCmpCaseCC
	ajStrCmp
	ajStrCmpO
	ajStrCmpWild
	ajStrCmpWildC
	ajStrCmpWildCC
	ajStrConvert
	ajStrConvertCC
	ajStrCopy
	ajStrCopyC
	ajStrCountC
	ajStrCountK
	ajStrCut
	ajStrDegap
	ajStrDel
	ajStrDelim
	ajStrDelReuse
	ajStrDup
	ajStrExit
	ajStrFind
	ajStrFindAny
	ajStrFindAnyC
	ajStrFindC
	ajStrFindCase
	ajStrFindCaseC
	ajStrFindK
	ajStrFill
	ajStrFix
	ajStrFixI
	ajStrFixTestI
	ajStrFromBool
	ajStrFromDouble
	ajStrFromDoubleE
	ajStrFromFloat
	ajStrFromInt
	ajStrFromLong
	ajStrInsert
	ajStrInsertC
	ajStrInsertK
	ajStrIsAlnum
	ajStrIsAlpha
	ajStrIsBool
	ajStrIsDouble
	ajStrIsFloat
	ajStrIsHex
	ajStrIsInt
	ajStrIsLong
	ajStrIsLower
	ajStrIsNum
	ajStrIsSpace
	ajStrIsUpper
	ajStrIsWild
	ajStrIsWhite
	ajStrIsWord
	ajStrIter
	ajStrIterBack
	ajStrIterBackNext
	ajStrIterFree
	ajStrIterNext
	ajStrJoin
	ajStrJoinC
	ajStrKeepAlphaC
	ajStrKeepC
	ajStrLen
	ajStrListToArray
	ajStrMask
	ajStrMatch
	ajStrMatchC
	ajStrMatchCase
	ajStrMatchCaseC
	ajStrMatchCaseCC
	ajStrMatchCC
	ajStrMatchWild
	ajStrMatchWildC
	ajStrMatchWildCC
	ajStrMatchWildCO
	ajStrMatchWord
	ajStrMatchWordC
	ajStrMatchWordCC
	ajStrMod
	ajStrModL
	ajStrModMinL
	ajStrNCmpC
	ajStrNCmpCaseCC
	ajStrNCmpO
	ajStrNew
	ajStrNewC
	ajStrNewCIL
	ajStrNewCL
	ajStrNewL
	ajStrNewS
	ajStrNull
	ajStrParentheses
	ajStrPos
	ajStrPosI
	ajStrPosII
	ajStrPrefix
	ajStrPrefixC
	ajStrPrefixCC
	ajStrPrefixCase
	ajStrPrefixCaseC
	ajStrPrefixCaseCC
	ajStrPrefixCaseCO
	ajStrPrefixCO
	ajStrQuote
	ajStrQuoteStrip
	ajStrQuoteStripAll
	ajStrRandom
	ajStrReplace
	ajStrReplaceC
	ajStrReplaceK
	ajStrReplaceS
	ajStrRef
	ajStrRemoveCharsC
	ajStrRemoveHtml
	ajStrRemoveNewline
	ajStrRev
	ajStrRFindC
	ajStrRoom
	ajStrSet
	ajStrSetC
	ajStrSize
	ajStrStat
	ajStrStr
	ajStrStrMod
	ajStrSub
	ajStrSubstitute
	ajStrSubstituteCC
	ajStrSubstituteKK
	ajStrSuffix
	ajStrSuffixC
	ajStrSuffixCC
	ajStrSuffixCO
	ajStrToBool
	ajStrToDouble
	ajStrToFloat
	ajStrToHex
	ajStrToInt
	ajStrTok
	ajStrTokC
	ajStrTokCC
	ajStrToken
	ajStrTokenAss
	ajStrTokenClear
	ajStrTokenCount
	ajStrTokenCountR
	ajStrTokenInit
	ajStrTokenReset
	ajStrTokenRest
	ajStrTokenTrace
	ajStrToLong
	ajStrToLower
	ajStrToLowerII
	ajStrToTitle
	ajStrToUpper
	ajStrToUpperII
	ajStrTrace
	ajStrTraceChars
	ajStrTraceT
	ajStrTrim
	ajStrTrimC
	ajStrTrimEndC
	ajStrTrimStartC
	ajStrTruncate
	ajStrWhole
	ajStrWildPrefix
	ajStrWrap
	ajStrWrapLeft
	ajStrUncomment
	ajStrUncommentStart
	ajStrYN
	ajTimeToday
	ajTimeTodayF
	ajTimeTodayRef
	ajTimeTodayRefF
	ajTimeTrace
	ajTimeSet
	ajTimeNew
	ajTimeDel
	ajTrnDel
	ajTrnNew
	ajTrnNewI
	ajTrnNewC
	ajTrnReadFile
	ajTrnNewPep
	ajTrnCodon
	ajTrnRevCodon
	ajTrnCodonC
	ajTrnRevCodonC
	ajTrnCodonK
	ajTrnRevCodonK
	ajTrnC
	ajTrnRevC
	ajTrnAltRevC
	ajTrnStr
	ajTrnRevStr
	ajTrnAltRevStr
	ajTrnSeq
	ajTrnRevSeq
	ajTrnAltRevSeq
	ajTrnCFrame
	ajTrnName
	ajTrnStrFrame
	ajTrnSeqFrame
	ajTrnSeqFramePep
	ajTrnCDangle
	ajTrnStrDangle
	ajTrnGetTitle
	ajTrnGetFileName
	ajTrnStartStop
	ajTrnStartStopC
	ajTrnSeqOrig
	ajTreeAddData
	ajTreeAddNode
	ajTreeAddSubNode
	ajTreeCopy
	ajTreeDel
	ajTreeExit
	ajTreeFree
	ajTreeLength
	ajTreeNew
	ajTreestrCopy
	ajTreestrDel
	ajTreestrFree
	ajTreestrNew
	ajTreestrToArray
	ajTreeTrace
	ajTreeDummyFunction
	ajExit
	ajExitAbort
	ajExitBad
	ajLogInfo
	ajUtilBigendian
	ajUtilCatch
	ajUtilRev2
	ajUtilRev4
	ajUtilRev8
	ajUtilRevInt
	ajUtilRevShort
	ajUtilRevLong
	ajUtilUid
	aj3dVectorAngle
	aj3dVectorBetweenPoints
	aj3dVectorCreate
	aj3dVectorCrossProduct
	aj3dVectorDihedralAngle
	aj3dVectorDel
	aj3dVectorDotProduct
	aj3dVectorLength
	aj3dVectorNew
	aj3dVectorSum
	ajXyzPdbtospNew
	ajXyzPdbtospDel
	ajXyzPdbtospRead
	ajXyzPdbtospReadC
	ajXyzPdbtospReadAll
	ajXyzPdbtospBinSearch
	ajXyzSortPdbtospPdb
	ajXyzAtomNew
	ajXyzAtomDel
	ajXyzInContact
	ajXyzAtomDistance
	ajXyzChainNew
	ajXyzChainDel
	ajXyzPdbNew
	ajXyzPdbDel
	ajXyzPdbWriteAll
	ajXyzPdbWriteDomain
	ajXyzPdbChain
	ajXyzPdbAtomIndexI
	ajXyzPdbAtomIndexC
	ajXyzPdbAtomIndexICA
	ajXyzPdbAtomIndexCCA
	ajXyzPdbToSp
	ajXyzPdbToAcc
	ajXyzCpdbRead
	ajXyzCpdbReadFirstModel
	ajXyzCpdbReadOld
	ajXyzCpdbWriteAll
	ajXyzCpdbWriteDomain
	ajXyzScopNew
	ajXyzScopDel
	ajXyzScopRead
	ajXyzScopReadC
	ajXyzScopReadAll
	ajXyzScopWrite
	ajXyzScopToPdb
	ajXyzScopToSp
	ajXyzScopToAcc
	ajXyzScopToScophit
	ajXyzScopCompId
	ajXyzScopCopy
	ajXyzScopclaNew
	ajXyzScopclaDel
	ajXyzScopclaRead
	ajXyzScopclaReadC
	ajXyzScopdesNew
	ajXyzScopdesDel
	ajXyzScopdesRead
	ajXyzScopdesReadC
	ajXyzScophitNew
	ajXyzScophitDel
	ajXyzScophitsToHitlist
	ajXyzScophitsOverlap
	ajXyzScophitsOverlapAcc
	ajXyzScophitCopy
	ajXyzScophitListCopy
	ajXyzScophitToHit
	ajXyzScophitCheckTarget
	ajXyzScophitTarget
	ajXyzScophitTarget2
	ajXyzScophitTargetLowPriority
	ajXyzScophitMergeInsertThis
	ajXyzScophitMergeInsertOther
	ajXyzScophitMerge
	ajXyzScophitCompSpr
	ajXyzScophitCompStart
	ajXyzScophitCompFold
	ajXyzScophitCompSfam
	ajXyzScophitCompFam
	ajXyzScophitCompAcc
	ajXyzHitNew
	ajXyzHitDel
	ajXyzHitsOverlap
	ajXyzCompScore
	ajXyzCompScoreInv
	ajXyzCompId
	ajXyzHitlistNew
	ajXyzHitlistDel
	ajXyzHitlistRead
	ajXyzHitlistReadNode
	ajXyzHitlistReadFam
	ajXyzHitlistReadSfam
	ajXyzHitlistReadFold
	ajXyzHitlistWrite
	ajXyzHitlistToScophits
	ajXyzHitlistClassify
	ajXyzHitlistPriorityHigh
	ajXyzHitlistPriorityLow
	ajXyzHitlistToThreeScophits
	ajXyzHitlistsWriteFasta
	ajXyzPrintPdbSeqresChain
	ajXyzPrintPdbSeqresDomain
	ajXyzPrintPdbAtomChain
	ajXyzPrintPdbAtomDomain
	ajXyzPrintPdbHeterogen
	ajXyzPrintPdbText
	ajXyzPrintPdbHeader
	ajXyzPrintPdbHeaderScop
	ajXyzPrintPdbTitle
	ajXyzPrintPdbCompnd
	ajXyzPrintPdbSource
	ajXyzPrintPdbEmptyRemark
	ajXyzPrintPdbResolution
	ajXyzScopalgRead
	ajXyzScopalgWrite
	ajXyzScopalgWriteClustal
	ajXyzScopalgWriteClustal2
	ajXyzScopalgNew
	ajXyzScopalgDel
	ajXyzScopalgGetseqs
	ajXyzCmapNew
	ajXyzCmapDel
	ajXyzCmapRead
	ajXyzCmapReadC
	ajXyzCmapReadI
	ajXyzVdwRad
	ajXyzVdwallNew
	ajXyzVdwallDel
	ajXyzVdwallRead
	ajXyzVdwresNew
	ajXyzVdwresDel
	ajXyzScorealgNew
	ajXyzScorealgDel
	ajXyzSigdatNew
	ajXyzSigposNew
	ajXyzSigdatDel
	ajXyzSigposDel
	ajXyzHitidxNew
	ajXyzHitidxDel
	ajXyzHitidxBinSearch
	ajXyzSignatureNew
	ajXyzSignatureDel
	ajXyzSignatureRead
	ajXyzSignatureWrite
	ajXyzSignatureCompile
	ajXyzSignatureAlignSeq
	ajXyzSignatureAlignSeqall
	ajXyzSignatureHitsWrite
	ajXyzSignatureAlignWrite
	ajXyzHetentNew
	ajXyzHetentDel
	ajXyzHetNew
	ajXyzHetDel
	ajXyzHetRawRead
	ajXyzHetRead
	ajXyzHetWrite
	embComComplexity
	embComWriteValueOfSeq
	embComWriteFile
	embComUnused
	embConsCalc
	embDataListDel
	embDataListGetTable
	embDataListGetTables
	embDataListRead
	embDbiCmpId
	embDbiCmpFieldId
	embDbiCmpFieldField
	embDbiEntryNew
	embDbiFieldNew
	embDbiFileIn
	embDbiFileIndex
	embDbiFileList
	embDbiFileListExc
	embDbiFileOut
	embDbiFileSingle
	embDbiFlatOpenlib
	embDbiHeaderSize
	embDbiMaxlen
	embDbiMemEntry
	embDbiRmEntryFile
	embDbiRmFile
	embDbiRmFileI
	embDbiSortClose
	embDbiSortFile
	embDbiSortWriteEntry
	embDbiSysCmd
	embDbiWriteDivisionRecord
	embDbiWriteEntryRecord
	embDbiWriteHit
	embDbiWriteTrg
	embDmxHitlistToScophits
	embDmxScophitsToHitlist
	embDmxScophitToHit
	embDmxScophitsAccToHitlist
	embDmxScopToScophit
	embDmxScopalgToScop
	embDmxScophitsOverlap
	embDmxScophitsOverlapAcc
	embDmxScophitMerge
	embDmxScophitMergeInsertThis
	embDmxScophitMergeInsertThisTarget
	embDmxScophitMergeInsertThisTargetBoth
	embDmxScophitMergeInsertOther
	embDmxScophitMergeInsertOtherTargetBoth
	embDmxScophitMergeInsertOtherTarget
	embDmxSeqNR
	embDmxSeqNRRange
	embDmxSeqCompall
	embScopToPdbid
	embScopToSp
	embScopToAcc
	embEstAlignNonRecursive
	embEstAlignLinearSpace
	embEstFindSpliceSites
	embEstFreeAlign
	embEstGetSeed
	embEstMatInit
	embEstOutBlastStyle
	embEstPrintAlign
	embEstSetDebug
	embEstSetVerbose
	embEstShuffleSeq
	embExit
	embGrpCompareTwoGnodes
	embGrpGroupsListDel
	embGrpKeySearchProgs
	embGrpKeySearchSeeAlso
	embGrpOutputGroupsList
	embGrpOutputProgsList
	embGrpSortGroupsList
	embGrpMakeUnique
	embBtreeEmblAC
	embBtreeEmblKW
	embBtreeEmblDE
	embBtreeGenBankAC
	embBtreeGenBankKW
	embBtreeGenBankDE
	embBtreeGenBankTX
	embBtreeFastaDE
	embBtreeReadDir
	embBtreeEntryNew
	embBtreeEntryDel
	embBtreeSetDbInfo
	embBtreeGetFiles
	embBtreeWriteEntryFile
	embBtreeGetRsInfo
	embBtreeOpenCaches
	embBtreeCloseCaches
	embBtreeDumpParameters
	embMatMatchDel
	embMatPrintsInit
	embMatProtDelInt
	embMatProtReadInt
	embMatProtScanInt
	embMiscMatchPattern
	embMolGetFrags
	embNmerNuc2int
	embNmerInt2nuc
	embNmerProt2int
	embNmerInt2prot
	embNmerGetNoElements
	embAtomInContact
	embAtomDistance
	embPdbToIdx
	embPdbListHeterogens
	embPdbidToSp
	embPdbidToAcc
	embPdbidToScop
	embVdwRad
	embStrideToThree
	embPropAminoRead
	embPropCalcFragments
	embPropCalcMolextcoeff
	embPropCalcMolwt
	embPropCalcMolwtMod
	embPropCharToThree
	embPropIntToThree
	embPropProtGaps
	embPropProt1to3
	embPropPurine
	embPropPyrimidine
	embPropTransversion
	embPropTransition
	embShowNew
	embShowDel
	embShowAddSeq
	embShowAddBlank
	embShowAddTicks
	embShowAddTicknum
	embShowAddComp
	embShowAddTran
	embShowAddRE
	embShowAddFT
	embShowAddNote
	embShowPrint
	embShowUpperRange
	embShowColourRange
	embWordBuildMatchTable
	embWordClear
	embWordFreeTable
	embWordGetTable
	embWordLength
	embWordMatchIter
	embWordMatchListDelete
	embWordMatchListPrint
	embWordPrintTable
	embWordPrintTableF
	embWordMatchListConvToFeat
	embWordMatchMin
	);

# --- list ajAcdGet... methods of EMBOSS for the EXPORT :acd tag

@ACD_METHODS = qw(
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetCpdb
	ajAcdGetDatafile
	ajAcdGetDirectory
	ajAcdGetDirectoryName
	ajAcdGetDirlist
	ajAcdGetDiscretestates
	ajAcdGetDiscretestatesI
	ajAcdGetDistances
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetFrequencies
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListI
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutcodon
	ajAcdGetOutcpdb
	ajAcdGetOutdata
	ajAcdGetOutdir
	ajAcdGetOutdirName
	ajAcdGetOutdiscrete
	ajAcdGetOutdistance
	ajAcdGetOutfile
	ajAcdGetOutfileall
	ajAcdGetOutfreq
	ajAcdGetOutmatrix
	ajAcdGetOutmatrixf
	ajAcdGetOutproperties
	ajAcdGetOutscop
	ajAcdGetOuttree
	ajAcdGetProperties
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectI
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetSeqsetall
	ajAcdGetSeqsetallI
	ajAcdGetString
	ajAcdGetToggle
	ajAcdGetTree
	ajAcdGetTreeI
	);

1;
